  /******************************************************************************
   *  PICL_STD_8K_20MHz_220327.ino  (220327)                                    *
   *                                                                            *
   *  Mike McLaren, K8LH                                                        *
   *  Micro Application Consultants                                             *
   *                                                                            *
   *  Programmer for 16F18877 upgrade to Karen Orton's PICL 8K board.           *
   *  SC/MP Emulator Engine - (C) 2007, Karen Orton.                            *
   *  Nat'Semi' 4K NIBL (National Industrial BASIC Language) included.          *
   *  Kitbug+ Monitor included with kind permission of Phil_G (G4PHL).          *
   *  Use original 20-MHz crystal.                                              *
   *  Serial port is 9600 baud (8/N/1) with local echo on terminal.             *
   *  Arduino Program based in part on work by Jaromir Sukuba.                  *
   *                                                                            *
   *  27-Mar-2022    Arduino 1.8.13 / Arduino Uno or Nano                       *
   ******************************************************************************/

  /******************************************************************************
   *  function prototypes                                                       *
   ******************************************************************************/

  /******************************************************************************
   *  hardware constants, helper macros, variables                              *
   ******************************************************************************/

   #define vcc    PORTD2    // D2 --> PIC pin 11 & 32
   #define clk    PORTD3    // D3 --> PIC pin 39
   #define dat    PORTD4    // D4 --> PIC pin 40
   #define clr    PORTD5    // D5 --> PIC pin  1

   #define cbi(sfr, bit) (_SFR_BYTE(sfr) &= ~(1<<bit))  // clear bit
   #define sbi(sfr, bit) (_SFR_BYTE(sfr) |= 1<<bit)     // set bit
   #define nop() asm volatile ("nop")

   #define icspDat(x) (x) ? sbi(PORTD,dat) : cbi(PORTD,dat)
   #define icspClk(x) (x) ? sbi(PORTD,clk) : cbi(PORTD,clk)
   #define icspVcc(x) (x) ? sbi(PORTD,vcc) : cbi(PORTD,vcc)
   #define icspClr(x) (x) ? sbi(PORTD,clr) : cbi(PORTD,clr)

   #define datOut()  DDRD |= 0x10   // set icspDat pin to 'output'
   #define datInp()  DDRD &= 0xEF   // set icspDat pin to 'input'

   #define uh(x) ((x >> 24) & 0xFF)
   #define ul(x) ((x >> 16) & 0xFF)
   #define hi(x) ((x >> 8) & 0xFF)
   #define lo(x) ((x >> 0) & 0xFF)

   #define hiNibble(x) ((x >> 4) & 0x0F)
   #define loNibble(x) ((x >> 0) & 0x0F)

   #define rom   pgm_read_word_near // 

   #define exitProgMode() icspClr(1); icspVcc(0); icspClr(0)

   const char hex[] = "0123456789ABCDEF";
   
   const uint16_t cfgmem[] PROGMEM = 
   { 0x1FFA,0x3F3D,0x3F9F,0x3FFF,0x3FFF };
   const uint16_t pg0[] PROGMEM = 
   { 0x018B,0x017E,0x01B8,0x01C3,0x01CE,0x01D9,0x01E4,0x3030, //  1   0>8
     0x00B9,0x3003,0x00E5,0x0140,0x0196,0x30E0,0x0099,0x0097, //  2   8>10
     0x3002,0x009A,0x3030,0x0091,0x0192,0x0193,0x0194,0x30FF, //  3   10>18
     0x0092,0x3001,0x0095,0x014F,0x305B,0x0096,0x30FF,0x0097, //  4   18>20
     0x3067,0x0098,0x307F,0x0099,0x3077,0x009A,0x30DF,0x009B, //  5   20>28
     0x0140,0x1E8C,0x28D1,0x21F7,0x340A,0x340D,0x3420,0x344C, //  6   28>30
     0x346F,0x3461,0x3464,0x3469,0x346E,0x3467,0x3420,0x3452, //  7   30>38
     0x3441,0x344D,0x3420,0x3449,0x346D,0x3461,0x3467,0x3465, //  8   38>40
     0x343A,0x3420,0x3424,0x3431,0x3431,0x3430,0x3430,0x342D, //  9   40>48
     0x3424,0x3432,0x3446,0x3446,0x3446,0x3400,0x2101,0x20FC, //  10   48>50
     0x21F7,0x340A,0x340D,0x340A,0x3420,0x3450,0x3449,0x3443, //  11   50>58
     0x344C,0x342F,0x344E,0x3449,0x3442,0x344C,0x3420,0x3438, //  12   58>60
     0x344B,0x3420,0x342D,0x3420,0x3428,0x3443,0x3429,0x3420, //  13   60>68
     0x344B,0x3461,0x3472,0x3465,0x346E,0x3420,0x344F,0x3472, //  14   68>70
     0x3474,0x346F,0x346E,0x340A,0x340D,0x3400,0x3020,0x00F5, //  15   70>78
     0x3002,0x00F6,0x3010,0x00F7,0x301C,0x00F8,0x1A0C,0x3207, //  16   78>80
     0x302F,0x00F3,0x30FB,0x00F4,0x3088,0x008A,0x2910,0x21F7, //  17   80>88
     0x3420,0x345B,0x3443,0x345D,0x346F,0x346C,0x3464,0x342C, //  18   88>90
     0x3420,0x345B,0x3457,0x345D,0x3461,0x3472,0x346D,0x342C, //  19   90>98
     0x3420,0x345B,0x344B,0x345D,0x3469,0x3474,0x3462,0x3475, //  20   98>A0
     0x3467,0x342B,0x3420,0x344D,0x346F,0x346E,0x3469,0x3474, //  21   A0>A8
     0x346F,0x3472,0x343F,0x3420,0x3400,0x21BF,0x3A43,0x1D03, //  22   A8>B0
     0x28B6,0x3000,0x00F3,0x3000,0x00F4,0x3213,0x3A14,0x1D03, //  23   B0>B8
     0x28BE,0x3000,0x00F3,0x3042,0x00F4,0x320B,0x3A1C,0x1D03, //  24   B8>C0
     0x2887,0x3009,0x00F9,0x306F,0x00FA,0x302C,0x00F3,0x3000, //  25   C0>C8
     0x00F4,0x21F7,0x340A,0x340D,0x340A,0x3400,0x3088,0x008A, //  26   C8>D0
     0x2910,0x21F7,0x340A,0x340D,0x340A,0x3420,0x345B,0x344C, //  27   D0>D8
     0x345D,0x346F,0x3461,0x3464,0x3420,0x3448,0x3445,0x3458, //  28   D8>E0
     0x342C,0x3420,0x345B,0x3453,0x345D,0x3461,0x3476,0x3465, //  29   E0>E8
     0x3420,0x3474,0x346F,0x3420,0x3446,0x346C,0x3461,0x3473, //  30   E8>F0
     0x3468,0x343F,0x3420,0x3400,0x21BF,0x3A4C,0x1903,0x2968, //  31   F0>F8
     0x3A1F,0x1903,0x2920,0x33D5,0x30A0,0x0085,0x0184,0x3021, //  32   F8>100
     0x3204,0x30A1,0x0085,0x0184,0x3040,0x00FF,0x0804,0x00F4, //  33   100>108
     0x0805,0x3EF0,0x00F3,0x0012,0x00F2,0x0192,0x0872,0x008D, //  34   108>110
     0x0874,0x0098,0x0873,0x38E0,0x0099,0x393F,0x0099,0x38E0, //  35   110>118
     0x0099,0x0992,0x0805,0x397F,0x067F,0x1D03,0x2906,0x0008, //  36   118>120
     0x0150,0x3011,0x00F3,0x3000,0x00F4,0x0873,0x3E10,0x009B, //  37   120>128
     0x0874,0x009A,0x131E,0x161E,0x151E,0x2161,0x121E,0x151E, //  38   128>130
     0x169E,0x0873,0x3E10,0x009B,0x0874,0x009A,0x0140,0x0874, //  39   130>138
     0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  40   138>140
     0x1699,0x1799,0x0150,0x009C,0x0AF4,0x1903,0x0AF3,0x0874, //  41   140>148
     0x391F,0x1903,0x129E,0x2161,0x0874,0x391F,0x1D03,0x292F, //  42   148>150
     0x0873,0x3A2C,0x1D03,0x2925,0x21F7,0x340A,0x340D,0x3420, //  43   150>158
     0x3464,0x346F,0x346E,0x3465,0x3420,0x340A,0x340D,0x3400, //  44   158>160
     0x284F,0x3055,0x009F,0x30AA,0x009F,0x149E,0x111E,0x0008, //  45   160>168
     0x21F7,0x340A,0x340D,0x340A,0x3420,0x3453,0x3465,0x346E, //  46   168>170
     0x3464,0x3420,0x3448,0x3465,0x3478,0x3420,0x3446,0x3469, //  47   170>178
     0x346C,0x3465,0x3420,0x344E,0x346F,0x3477,0x340A,0x340D, //  48   178>180
     0x3400,0x21BF,0x3A3A,0x1D03,0x2981,0x21B0,0x00F4,0x21B0, //  49   180>188
     0x00FC,0x21B0,0x00FD,0x21B0,0x00F3,0x1D03,0x29A0,0x21B0, //  50   188>190
     0x0192,0x0872,0x008D,0x087D,0x0098,0x087C,0x38E0,0x0099, //  51   190>198
     0x393F,0x0099,0x38E0,0x0099,0x0992,0x0AFD,0x0BF4,0x298F, //  52   198>1A0
     0x21B0,0x0B73,0x2981,0x21F7,0x340A,0x340D,0x3420,0x3464, //  53   1A0>1A8
     0x346F,0x346E,0x3465,0x3420,0x340A,0x340D,0x3400,0x284F, //  54   1A8>1B0
     0x01F2,0x21B3,0x0EF2,0x21BF,0x3EC0,0x1C03,0x3E07,0x3E09, //  55   1B0>1B8
     0x07F2,0x0872,0x0008,0x21BF,0x3088,0x008A,0x2910,0x1810, //  56   1B8>1C0
     0x29BF,0x3001,0x00FF,0x3031,0x2206,0x3009,0x00F0,0x0CF1, //  57   1C0>1C8
     0x3001,0x00FF,0x3064,0x2208,0x1003,0x1810,0x1403,0x0BF0, //  58   1C8>1D0
     0x29C7,0x13F1,0x0871,0x00F0,0x0008,0x21E3,0x3088,0x008A, //  59   1D0>1D8
     0x2910,0x00F3,0x21DB,0x0E73,0x00F3,0x390F,0x3E36,0x1883, //  60   1D8>1E0
     0x3E07,0x3EFA,0x00F0,0x0140,0x13F0,0x300B,0x00F1,0x1003, //  61   1E0>1E8
     0x3206,0x3001,0x00FF,0x3063,0x2206,0x1403,0x0CF0,0x081A, //  62   1E8>1F0
     0x3802,0x1C03,0x3A02,0x009A,0x0BF1,0x33F3,0x0008,0x017F, //  63   1F0>1F8
     0x086E,0x0086,0x086F,0x0087,0x1787,0x0AEE,0x1903,0x0AEF, //  64   1F8>200
     0x0140,0x0801,0x1903,0x0008,0x21E2,0x33F1,0x0000,0x0000, //  65   200>208
     0x0000,0x0000,0x3EFF,0x1C03,0x0BFF,0x2A0A,0x0008,0x01F0, //  66   208>210
     0x1810,0x16F0,0x3088,0x008A,0x2910,0x0870,0x00FF,0x0871, //  67   210>218
     0x00F0,0x087F,0x00F1,0x3088,0x008A,0x2910,0x0870,0x00FF, //  68   218>220
     0x0874,0x00F0,0x087F,0x00F4,0x3088,0x008A,0x2910,0x0870, //  69   220>228
     0x00FF,0x0876,0x00F0,0x087F,0x00F6,0x3088,0x008A,0x2910, //  70   228>230
     0x0870,0x00FF,0x0878,0x00F0,0x087F,0x00F8,0x3088,0x008A, //  71   230>238
     0x2910,0x0870,0x00FF,0x087A,0x00F0,0x087F,0x00FA,0x3088, //  72   238>240
     0x008A,0x2910,0x0870,0x00FF,0x0873,0x00F0,0x087F,0x00F3, //  73   240>248
     0x3088,0x008A,0x2910,0x0870,0x00FF,0x0875,0x00F0,0x087F, //  74   248>250
     0x00F5,0x3088,0x008A,0x2910,0x0870,0x00FF,0x0877,0x00F0, //  75   250>258
     0x087F,0x00F7,0x3088,0x008A,0x2910,0x0870,0x00FF,0x0879, //  76   258>260
     0x00F0,0x087F,0x00F9,0x3088,0x008A,0x2910,0x25FD,0x00F0, //  77   260>268
     0x3088,0x008A,0x2910,0x263B,0x00F0,0x3088,0x008A,0x2910, //  78   268>270
     0x2679,0x00F0,0x3088,0x008A,0x2910,0x26B7,0x00F0,0x3088, //  79   270>278
     0x008A,0x2910,0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0,0x1D03, //  80   278>280
     0x2A87,0x25D9,0x00FB,0x3000,0x008A,0x087B,0x2A93,0x0874, //  81   280>288
     0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  82   288>290
     0x1699,0x1799,0x00FB,0x3A80,0x1D03,0x2A98,0x0871,0x00FB, //  83   290>298
     0x0873,0x00FC,0x1BFB,0x03FC,0x087B,0x0774,0x00FD,0x1803, //  84   298>2A0
     0x0AFC,0x087C,0x39F0,0x1D03,0x2AAB,0x25DE,0x00FE,0x3000, //  85   2A0>2A8
     0x008A,0x087E,0x2AB7,0x087D,0x0098,0x087C,0x38E0,0x0099, //  86   2A8>2B0
     0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FE,0x087E, //  87   2B0>2B8
     0x0670,0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0, //  88   2B8>2C0
     0x1803,0x17F2,0x0670,0x05FF,0x1372,0x1BFF,0x1772,0x3088, //  89   2C0>2C8
     0x008A,0x2910,0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0,0x1D03, //  90   2C8>2D0
     0x2AD7,0x25D9,0x00FB,0x3000,0x008A,0x087B,0x2AE3,0x0874, //  91   2D0>2D8
     0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  92   2D8>2E0
     0x1699,0x1799,0x00FB,0x3A80,0x1D03,0x2AE8,0x0871,0x00FB, //  93   2E0>2E8
     0x0875,0x00FC,0x1BFB,0x03FC,0x087B,0x0776,0x00FD,0x1803, //  94   2E8>2F0
     0x0AFC,0x087C,0x39F0,0x1D03,0x2AFB,0x25DE,0x00FE,0x3000, //  95   2F0>2F8
     0x008A,0x087E,0x2B07,0x087D,0x0098,0x087C,0x38E0,0x0099, //  96   2F8>300
     0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FE,0x087E, //  97   300>308
     0x0670,0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0, //  98   308>310
     0x1803,0x17F2,0x0670,0x05FF,0x1372,0x1BFF,0x1772,0x3088, //  99   310>318
     0x008A,0x2910,0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0,0x1D03, //  100   318>320
     0x2B27,0x25D9,0x00FB,0x3000,0x008A,0x087B,0x2B33,0x0874, //  101   320>328
     0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  102   328>330
     0x1699,0x1799,0x00FB,0x3A80,0x1D03,0x2B38,0x0871,0x00FB, //  103   330>338
     0x0877,0x00FC,0x1BFB,0x03FC,0x087B,0x0778,0x00FD,0x1803, //  104   338>340
     0x0AFC,0x087C,0x39F0,0x1D03,0x2B4B,0x25DE,0x00FE,0x3000, //  105   340>348
     0x008A,0x087E,0x2B57,0x087D,0x0098,0x087C,0x38E0,0x0099, //  106   348>350
     0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FE,0x087E, //  107   350>358
     0x0670,0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0, //  108   358>360
     0x1803,0x17F2,0x0670,0x05FF,0x1372,0x1BFF,0x1772,0x3088, //  109   360>368
     0x008A,0x2910,0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0,0x1D03, //  110   368>370
     0x2B77,0x25D9,0x00FB,0x3000,0x008A,0x087B,0x2B83,0x0874, //  111   370>378
     0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  112   378>380
     0x1699,0x1799,0x00FB,0x3A80,0x1D03,0x2B88,0x0871,0x00FB, //  113   380>388
     0x0879,0x00FC,0x1BFB,0x03FC,0x087B,0x077A,0x00FD,0x1803, //  114   388>390
     0x0AFC,0x087C,0x39F0,0x1D03,0x2B9B,0x25DE,0x00FE,0x3000, //  115   390>398
     0x008A,0x087E,0x2BA7,0x087D,0x0098,0x087C,0x38E0,0x0099, //  116   398>3A0
     0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FE,0x087E, //  117   3A0>3A8
     0x0670,0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0, //  118   3A8>3B0
     0x1803,0x17F2,0x0670,0x05FF,0x1372,0x1BFF,0x1772,0x3088, //  119   3B0>3B8
     0x008A,0x2910,0x25FD,0x09FE,0x087E,0x0670,0x3A80,0x00FF, //  120   3B8>3C0
     0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0,0x1803,0x17F2,0x0670, //  121   3C0>3C8
     0x05FF,0x1372,0x1BFF,0x1772,0x3088,0x008A,0x2910,0x263B, //  122   3C8>3D0
     0x09FE,0x087E,0x0670,0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2, //  123   3D0>3D8
     0x087E,0x07F0,0x1803,0x17F2,0x0670,0x05FF,0x1372,0x1BFF, //  124   3D8>3E0
     0x1772,0x3088,0x008A,0x2910,0x2679,0x09FE,0x087E,0x0670, //  125   3E0>3E8
     0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0,0x1803, //  126   3E8>3F0
     0x17F2,0x0670,0x05FF,0x1372,0x1BFF,0x1772,0x3088,0x008A, //  127   3F0>3F8
     0x2910,0x26B7,0x09FE,0x087E,0x0670,0x3A80,0x00FF,0x1BF2, //  128   3F8>400
     0x0FF0,0x13F2,0x087E,0x07F0,0x1803,0x17F2,0x0670,0x05FF, //  129   400>408
     0x1372,0x1BFF,0x1772,0x3088,0x008A,0x2910,0x25FD,0x05F0, //  130   408>410
     0x3088,0x008A,0x2910,0x263B,0x05F0,0x3088,0x008A,0x2910, //  131   410>418
     0x2679,0x05F0,0x3088,0x008A,0x2910,0x26B7,0x05F0,0x3088, //  132   418>420
     0x008A,0x2910,0x25FD,0x04F0,0x3088,0x008A,0x2910,0x263B, //  133   420>428
     0x04F0,0x3088,0x008A,0x2910,0x2679,0x04F0,0x3088,0x008A, //  134   428>430
     0x2910,0x26B7,0x04F0,0x3088,0x008A,0x2910,0x25FD,0x06F0, //  135   430>438
     0x3088,0x008A,0x2910,0x263B,0x06F0,0x3088,0x008A,0x2910, //  136   438>440
     0x2679,0x06F0,0x3088,0x008A,0x2910,0x26B7,0x06F0,0x3088, //  137   440>448
     0x008A,0x2910,0x25FD,0x26F5,0x3088,0x008A,0x2910,0x263B, //  138   448>450
     0x26F5,0x3088,0x008A,0x2910,0x2679,0x26F5,0x3088,0x008A, //  139   450>458
     0x2910,0x26B7,0x26F5,0x3088,0x008A,0x2910,0x25E3,0x00F0, //  140   458>460
     0x3088,0x008A,0x2910,0x25E3,0x05F0,0x3088,0x008A,0x2910, //  141   460>468
     0x25E3,0x04F0,0x3088,0x008A,0x2910,0x25E3,0x06F0,0x3088, //  142   468>470
     0x008A,0x2910,0x3066,0x07F1,0x1BF2,0x0AF0,0x0DF2,0x0871, //  143   470>478
     0x07F0,0x0CF2,0x3006,0x1C83,0x02F0,0x3060,0x1FF2,0x02F0, //  144   478>480
     0x3088,0x008A,0x2910,0x25E3,0x3066,0x07FB,0x1BF2,0x0AF0, //  145   480>488
     0x0DF2,0x087B,0x07F0,0x0CF2,0x3006,0x1C83,0x02F0,0x3060, //  146   488>490
     0x1FF2,0x02F0,0x3088,0x008A,0x2910,0x0AF3,0x0FF4,0x03F3, //  147   490>498
     0x0873,0x39F0,0x1D03,0x2CA2,0x25D9,0x00FB,0x3000,0x008A, //  148   498>4A0
     0x087B,0x2CAE,0x0874,0x0098,0x0873,0x38E0,0x0099,0x395F, //  149   4A0>4A8
     0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x09FB,0x087B, //  150   4A8>4B0
     0x0670,0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2,0x087B,0x07F0, //  151   4B0>4B8
     0x1803,0x17F2,0x0670,0x05FF,0x1372,0x1BFF,0x1772,0x3088, //  152   4B8>4C0
     0x008A,0x2910,0x25FD,0x3E01,0x00F0,0x2744,0x3088,0x008A, //  153   4C0>4C8
     0x2910,0x263B,0x3E01,0x00F0,0x2744,0x3088,0x008A,0x2910, //  154   4C8>4D0
     0x2679,0x3E01,0x00F0,0x2744,0x3088,0x008A,0x2910,0x26B7, //  155   4D0>4D8
     0x3E01,0x00F0,0x2744,0x3088,0x008A,0x2910,0x25FD,0x3EFF, //  156   4D8>4E0
     0x00F0,0x2744,0x3088,0x008A,0x2910,0x263B,0x3EFF,0x00F0, //  157   4E0>4E8
     0x2744,0x3088,0x008A,0x2910,0x2679,0x3EFF,0x00F0,0x2744, //  158   4E8>4F0
     0x3088,0x008A,0x2910,0x26B7,0x3EFF,0x00F0,0x2744,0x3088, //  159   4F0>4F8
     0x008A,0x2910,0x2704,0x2744,0x3088,0x008A,0x2910,0x2714, //  160   4F8>500
     0x2744,0x3088,0x008A,0x2910,0x2724,0x2744,0x3088,0x008A, //  161   500>508
     0x2910,0x2734,0x2744,0x3088,0x008A,0x2910,0x0AF3,0x0FF4, //  162   508>510
     0x03F3,0x0873,0x39F0,0x1D03,0x2D1B,0x25D9,0x00FB,0x3000, //  163   510>518
     0x008A,0x087B,0x2D27,0x0874,0x0098,0x0873,0x38E0,0x0099, //  164   518>520
     0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x3A80, //  165   520>528
     0x1D03,0x2D2C,0x0871,0x00FB,0x0875,0x00FC,0x1BFB,0x03FC, //  166   528>530
     0x087B,0x0776,0x00FD,0x1803,0x0AFC,0x1BFB,0x2D3F,0x2756, //  167   530>538
     0x087C,0x00F5,0x087D,0x00F6,0x3088,0x008A,0x2910,0x087C, //  168   538>540
     0x00F5,0x087D,0x00F6,0x2756,0x3088,0x008A,0x2910,0x0AF3, //  169   540>548
     0x0FF4,0x03F3,0x0873,0x39F0,0x1D03,0x2D54,0x25D9,0x00FB, //  170   548>550
     0x3000,0x008A,0x087B,0x2D60,0x0874,0x0098,0x0873,0x38E0, //  171   550>558
     0x0099,0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB, //  172   558>560
     0x3A80,0x1D03,0x2D65,0x0871,0x00FB,0x0877,0x00FC,0x1BFB, //  173   560>568
     0x03FC,0x087B,0x0778,0x00FD,0x1803,0x0AFC,0x1BFB,0x2D78, //  174   568>570
     0x2768,0x087C,0x00F7,0x087D,0x00F8,0x3088,0x008A,0x2910, //  175   570>578
     0x087C,0x00F7,0x087D,0x00F8,0x2768,0x3088,0x008A,0x2910, //  176   578>580
     0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0,0x1D03,0x2D8D,0x25D9, //  177   580>588
     0x00FB,0x3000,0x008A,0x087B,0x2D99,0x0874,0x0098,0x0873, //  178   588>590
     0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D,0x1699,0x1799, //  179   590>598
     0x00FB,0x3A80,0x1D03,0x2D9E,0x0871,0x00FB,0x0879,0x00FC, //  180   598>5A0
     0x1BFB,0x03FC,0x087B,0x077A,0x00FD,0x1803,0x0AFC,0x1BFB, //  181   5A0>5A8
     0x2DB1,0x277A,0x087C,0x00F9,0x087D,0x00FA,0x3088,0x008A, //  182   5A8>5B0
     0x2910,0x087C,0x00F9,0x087D,0x00FA,0x277A,0x3088,0x008A, //  183   5B0>5B8
     0x2910,0x25E3,0x08F0,0x1903,0x2DC5,0x0000,0x0000,0x0000, //  184   5B8>5C0
     0x0000,0x0000,0x263A,0x0BF0,0x2DBF,0x08FB,0x1903,0x2DD5, //  185   5C0>5C8
     0x0000,0x0000,0x0000,0x0000,0x0000,0x30E9,0x00FF,0x263A, //  186   5C8>5D0
     0x263A,0x0BFF,0x2DCF,0x0BFB,0x2DCA,0x03F0,0x3088,0x008A, //  187   5D0>5D8
     0x2910,0x0873,0x3E90,0x008A,0x0874,0x0082,0x087C,0x3E90, //  188   5D8>5E0
     0x008A,0x087D,0x0082,0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0, //  189   5E0>5E8
     0x1D03,0x2DF0,0x25D9,0x00FB,0x3000,0x008A,0x087B,0x2DFC, //  190   5E8>5F0
     0x0874,0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000, //  191   5F0>5F8
     0x080D,0x1699,0x1799,0x00FB,0x0008,0x0AF3,0x0FF4,0x03F3, //  192   5F8>600
     0x0873,0x39F0,0x1D03,0x2E0A,0x25D9,0x00FB,0x3000,0x008A, //  193   600>608
     0x087B,0x2E16,0x0874,0x0098,0x0873,0x38E0,0x0099,0x395F, //  194   608>610
     0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x3A80,0x1D03, //  195   610>618
     0x2E1B,0x0871,0x00FB,0x0873,0x00FC,0x1BFB,0x03FC,0x087B, //  196   618>620
     0x0774,0x00FD,0x1803,0x0AFC,0x087C,0x39F0,0x1D03,0x2E2E, //  197   620>628
     0x25DE,0x00FE,0x3000,0x008A,0x087E,0x2E3A,0x087D,0x0098, //  198   628>630
     0x087C,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D,0x1699, //  199   630>638
     0x1799,0x00FE,0x0008,0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0, //  200   638>640
     0x1D03,0x2E48,0x25D9,0x00FB,0x3000,0x008A,0x087B,0x2E54, //  201   640>648
     0x0874,0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000, //  202   648>650
     0x080D,0x1699,0x1799,0x00FB,0x3A80,0x1D03,0x2E59,0x0871, //  203   650>658
     0x00FB,0x0875,0x00FC,0x1BFB,0x03FC,0x087B,0x0776,0x00FD, //  204   658>660
     0x1803,0x0AFC,0x087C,0x39F0,0x1D03,0x2E6C,0x25DE,0x00FE, //  205   660>668
     0x3000,0x008A,0x087E,0x2E78,0x087D,0x0098,0x087C,0x38E0, //  206   668>670
     0x0099,0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FE, //  207   670>678
     0x0008,0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0,0x1D03,0x2E86, //  208   678>680
     0x25D9,0x00FB,0x3000,0x008A,0x087B,0x2E92,0x0874,0x0098, //  209   680>688
     0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D,0x1699, //  210   688>690
     0x1799,0x00FB,0x3A80,0x1D03,0x2E97,0x0871,0x00FB,0x0877, //  211   690>698
     0x00FC,0x1BFB,0x03FC,0x087B,0x0778,0x00FD,0x1803,0x0AFC, //  212   698>6A0
     0x087C,0x39F0,0x1D03,0x2EAA,0x25DE,0x00FE,0x3000,0x008A, //  213   6A0>6A8
     0x087E,0x2EB6,0x087D,0x0098,0x087C,0x38E0,0x0099,0x395F, //  214   6A8>6B0
     0x0099,0x0000,0x080D,0x1699,0x1799,0x00FE,0x0008,0x0AF3, //  215   6B0>6B8
     0x0FF4,0x03F3,0x0873,0x39F0,0x1D03,0x2EC4,0x25D9,0x00FB, //  216   6B8>6C0
     0x3000,0x008A,0x087B,0x2ED0,0x0874,0x0098,0x0873,0x38E0, //  217   6C0>6C8
     0x0099,0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB, //  218   6C8>6D0
     0x3A80,0x1D03,0x2ED5,0x0871,0x00FB,0x0879,0x00FC,0x1BFB, //  219   6D0>6D8
     0x03FC,0x087B,0x077A,0x00FD,0x1803,0x0AFC,0x087C,0x39F0, //  220   6D8>6E0
     0x1D03,0x2EE8,0x25DE,0x00FE,0x3000,0x008A,0x087E,0x2EF4, //  221   6E0>6E8
     0x087D,0x0098,0x087C,0x38E0,0x0099,0x395F,0x0099,0x0000, //  222   6E8>6F0
     0x080D,0x1699,0x1799,0x00FE,0x0008,0x3066,0x07FE,0x1BF2, //  223   6F0>6F8
     0x0AF0,0x0DF2,0x087E,0x07F0,0x0CF2,0x3006,0x1C83,0x02F0, //  224   6F8>700
     0x3060,0x1FF2,0x02F0,0x0008,0x25E3,0x3A80,0x1D03,0x2F0A, //  225   700>708
     0x0871,0x00FB,0x0873,0x00FC,0x1BFB,0x03FC,0x087B,0x0774, //  226   708>710
     0x00FD,0x1803,0x0AFC,0x0008,0x25E3,0x3A80,0x1D03,0x2F1A, //  227   710>718
     0x0871,0x00FB,0x0875,0x00FC,0x1BFB,0x03FC,0x087B,0x0776, //  228   718>720
     0x00FD,0x1803,0x0AFC,0x0008,0x25E3,0x3A80,0x1D03,0x2F2A, //  229   720>728
     0x0871,0x00FB,0x0877,0x00FC,0x1BFB,0x03FC,0x087B,0x0778, //  230   728>730
     0x00FD,0x1803,0x0AFC,0x0008,0x25E3,0x3A80,0x1D03,0x2F3A, //  231   730>738
     0x0871,0x00FB,0x0879,0x00FC,0x1BFB,0x03FC,0x087B,0x077A, //  232   738>740
     0x00FD,0x1803,0x0AFC,0x0008,0x087C,0x39F0,0x1903,0x0008, //  233   740>748
     0x0192,0x0870,0x008D,0x087D,0x0098,0x087C,0x38E0,0x0099, //  234   748>750
     0x393F,0x0099,0x38E0,0x0099,0x0992,0x0008,0x0875,0x39F0, //  235   750>758
     0x1903,0x0008,0x0192,0x0870,0x008D,0x0876,0x0098,0x0875, //  236   758>760
     0x38E0,0x0099,0x393F,0x0099,0x38E0,0x0099,0x0992,0x0008, //  237   760>768
     0x0877,0x39F0,0x1903,0x0008,0x0192,0x0870,0x008D,0x0878, //  238   768>770
     0x0098,0x0877,0x38E0,0x0099,0x393F,0x0099,0x38E0,0x0099, //  239   770>778
     0x0992,0x0008,0x0879,0x39F0,0x1903,0x0008,0x0192,0x0870, //  240   778>780
     0x008D,0x087A,0x0098,0x0879,0x38E0,0x0099,0x393F,0x0099, //  241   780>788
     0x38E0,0x0099,0x0992,0x0008,0xFF85,0xFFFF,0xFFFF,0xFFFF, //  242   788>790
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  243   790>798
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  244   798>7A0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  245   7A0>7A8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  246   7A8>7B0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  247   7B0>7B8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  248   7B8>7C0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  249   7C0>7C8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  250   7C8>7D0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  251   7D0>7D8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  252   7D8>7E0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  253   7E0>7E8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  254   7E8>7F0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  255   7F0>7F8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  256   7F8>800
     0x2910,0x2973,0x295F,0x2961,0x2963,0x2965,0x296C,0x2967, //  257   800>808
     0x2910,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  258   808>810
     0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  259   810>818
     0x2F71,0x294F,0x2F71,0x2F71,0x2956,0x295C,0x2959,0x293F, //  260   818>820
     0x2F73,0x2F75,0x2F77,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  261   820>828
     0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  262   828>830
     0x2975,0x2977,0x2979,0x297B,0x297D,0x297F,0x2981,0x2983, //  263   830>838
     0x2F71,0x2F71,0x2F71,0x2F71,0x2910,0x2985,0x2992,0x299F, //  264   838>840
     0x2943,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  265   840>848
     0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  266   848>850
     0x294C,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  267   850>858
     0x2946,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  268   858>860
     0x2949,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  269   860>868
     0x2D3F,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  270   868>870
     0x2900,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  271   870>878
     0x292B,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  272   878>880
     0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  273   880>888
     0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2D41, //  274   888>890
     0x2D7E,0x2DAE,0x2DDE,0x2E0E,0x29AC,0x29AF,0x29B2,0x29B5, //  275   890>898
     0x29B8,0x29BC,0x29C0,0x29C4,0x29C8,0x29CC,0x29D0,0x29D4, //  276   898>8A0
     0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  277   8A0>8A8
     0x29D8,0x29DA,0x29DC,0x29DE,0x2F71,0x2F71,0x2F71,0x2F71, //  278   8A8>8B0
     0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71,0x2F71, //  279   8B0>8B8
     0x29E0,0x29E2,0x29E4,0x29E6,0x2F71,0x2F71,0x2F71,0x2F71, //  280   8B8>8C0
     0x29E8,0x29EA,0x29EC,0x29EE,0x2D43,0x29F0,0x29F3,0x29F6, //  281   8C0>8C8
     0x2D45,0x2D47,0x2D49,0x2D4B,0x2F71,0x2D4D,0x2D4F,0x2D51, //  282   8C8>8D0
     0x29F9,0x29FB,0x29FD,0x29FF,0x2D53,0x2A01,0x2A04,0x2A07, //  283   8D0>8D8
     0x2A0A,0x2A0C,0x2A0E,0x2A10,0x2D55,0x2A12,0x2A15,0x2A18, //  284   8D8>8E0
     0x2A1B,0x2A1D,0x2A1F,0x2A21,0x2D57,0x2A23,0x2A26,0x2A29, //  285   8E0>8E8
     0x2A2C,0x2A2E,0x2A30,0x2A32,0x2D59,0x2A34,0x2A37,0x2A3A, //  286   8E8>8F0
     0x2A3D,0x2A3F,0x2A41,0x2A43,0x2A45,0x2A6F,0x2AEE,0x2B6D, //  287   8F0>8F8
     0x2D5B,0x2D5D,0x2D5F,0x2D61,0x2D63,0x2BEC,0x2C5D,0x2CCE, //  288   8F8>900
     0x0871,0x0670,0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2,0x0871, //  289   900>908
     0x07F0,0x1803,0x17F2,0x0670,0x05FF,0x1372,0x1BFF,0x1772, //  290   908>910
     0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0,0x1903,0x2923,0x0874, //  291   910>918
     0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  292   918>920
     0x1699,0x1799,0x0082,0x3090,0x0773,0x0085,0x0874,0x0084, //  293   920>928
     0x3188,0x0012,0x0082,0x0871,0x00FE,0x09FE,0x087E,0x0670, //  294   928>930
     0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0,0x1803, //  295   930>938
     0x17F2,0x0670,0x05FF,0x1372,0x1BFF,0x1772,0x2910,0x0DF2, //  296   938>940
     0x0CF0,0x0CF2,0x2910,0x0871,0x00F0,0x2910,0x0871,0x04F0, //  297   940>948
     0x2910,0x0871,0x06F0,0x2910,0x0871,0x05F0,0x2910,0x1871, //  298   948>950
     0x151A,0x1C71,0x111A,0x0CF1,0x17F1,0x2910,0x0CF0,0x13F0, //  299   950>958
     0x2910,0x0C70,0x0CF0,0x2910,0x0D72,0x0CF0,0x2910,0x13F2, //  300   958>960
     0x2910,0x17F2,0x2910,0x11F2,0x2910,0x15F2,0x2910,0x0870, //  301   960>968
     0x39CF,0x00F2,0x0096,0x2910,0x1272,0x12F2,0x080C,0x3930, //  302   968>970
     0x0472,0x00F0,0x2910,0x018A,0x2A15,0x018A,0x2A1E,0x018A, //  303   970>978
     0x2A27,0x018A,0x2A30,0x018A,0x2A39,0x018A,0x2A42,0x018A, //  304   978>980
     0x2A4B,0x018A,0x2A54,0x018A,0x2A5D,0x0875,0x00FF,0x0873, //  305   980>988
     0x00F5,0x087F,0x00F3,0x0876,0x00FF,0x0874,0x00F6,0x087F, //  306   988>990
     0x00F4,0x2910,0x0877,0x00FF,0x0873,0x00F7,0x087F,0x00F3, //  307   990>998
     0x0878,0x00FF,0x0874,0x00F8,0x087F,0x00F4,0x2910,0x0879, //  308   998>9A0
     0x00FF,0x0873,0x00F9,0x087F,0x00F3,0x087A,0x00FF,0x0874, //  309   9A0>9A8
     0x00FA,0x087F,0x00F4,0x2910,0x1FF0,0x2D7E,0x2E3E,0x1FF0, //  310   9A8>9B0
     0x2DAE,0x2E3E,0x1FF0,0x2DDE,0x2E3E,0x1FF0,0x2E0E,0x2E3E, //  311   9B0>9B8
     0x08F0,0x1903,0x2D7E,0x2E3E,0x08F0,0x1903,0x2DAE,0x2E3E, //  312   9B8>9C0
     0x08F0,0x1903,0x2DDE,0x2E3E,0x08F0,0x1903,0x2E0E,0x2E3E, //  313   9C0>9C8
     0x08F0,0x1D03,0x2D7E,0x2E3E,0x08F0,0x1D03,0x2DAE,0x2E3E, //  314   9C8>9D0
     0x08F0,0x1D03,0x2DDE,0x2E3E,0x08F0,0x1D03,0x2E0E,0x2E3E, //  315   9D0>9D8
     0x018A,0x2CC2,0x018A,0x2CC9,0x018A,0x2CD0,0x018A,0x2CD7, //  316   9D8>9E0
     0x018A,0x2CDE,0x018A,0x2CE5,0x018A,0x2CEC,0x018A,0x2CF3, //  317   9E0>9E8
     0x018A,0x2A66,0x018A,0x2A6B,0x018A,0x2A70,0x018A,0x2A75, //  318   9E8>9F0
     0x2642,0x00F0,0x2910,0x26A2,0x00F0,0x2910,0x2702,0x00F0, //  319   9F0>9F8
     0x2910,0x018A,0x2C0E,0x018A,0x2C13,0x018A,0x2C18,0x018A, //  320   9F8>A00
     0x2C1D,0x2642,0x05F0,0x2910,0x26A2,0x05F0,0x2910,0x2702, //  321   A00>A08
     0x05F0,0x2910,0x018A,0x2C22,0x018A,0x2C27,0x018A,0x2C2C, //  322   A08>A10
     0x018A,0x2C31,0x2642,0x04F0,0x2910,0x26A2,0x04F0,0x2910, //  323   A10>A18
     0x2702,0x04F0,0x2910,0x018A,0x2C36,0x018A,0x2C3B,0x018A, //  324   A18>A20
     0x2C40,0x018A,0x2C45,0x2642,0x06F0,0x2910,0x26A2,0x06F0, //  325   A20>A28
     0x2910,0x2702,0x06F0,0x2910,0x018A,0x2C4A,0x018A,0x2C4F, //  326   A28>A30
     0x018A,0x2C54,0x018A,0x2C59,0x2642,0x2762,0x2910,0x26A2, //  327   A30>A38
     0x2762,0x2910,0x2702,0x2762,0x2910,0x018A,0x2A7A,0x018A, //  328   A38>A40
     0x2ACA,0x018A,0x2B1A,0x018A,0x2B6A,0x0AF3,0x0FF4,0x03F3, //  329   A40>A48
     0x0873,0x39F0,0x1D03,0x2A52,0x2565,0x00FB,0x3008,0x008A, //  330   A48>A50
     0x087B,0x2A5E,0x0874,0x0098,0x0873,0x38E0,0x0099,0x395F, //  331   A50>A58
     0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x087B,0x0670, //  332   A58>A60
     0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2,0x087B,0x07F0,0x1803, //  333   A60>A68
     0x17F2,0x0670,0x05FF,0x1372,0x1BFF,0x1772,0x2910,0x0AF3, //  334   A68>A70
     0x0FF4,0x03F3,0x0873,0x39F0,0x1D03,0x2A7C,0x2565,0x00FB, //  335   A70>A78
     0x3088,0x008A,0x087B,0x2A88,0x0874,0x0098,0x0873,0x38E0, //  336   A78>A80
     0x0099,0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB, //  337   A80>A88
     0x3A80,0x1D03,0x2A8D,0x0871,0x00FB,0x0875,0x00FC,0x1BFB, //  338   A88>A90
     0x03FC,0x087B,0x0776,0x00FD,0x1803,0x0AFC,0x1BFB,0x2AC3, //  339   A90>A98
     0x0875,0x39F0,0x1D03,0x2AA2,0x256A,0x00FE,0x3088,0x008A, //  340   A98>AA0
     0x087E,0x2AAE,0x0876,0x0098,0x0875,0x38E0,0x0099,0x395F, //  341   AA0>AA8
     0x0099,0x0000,0x080D,0x1699,0x1799,0x00FE,0x087C,0x00F5, //  342   AA8>AB0
     0x087D,0x00F6,0x087E,0x0670,0x3A80,0x00FF,0x1BF2,0x0FF0, //  343   AB0>AB8
     0x13F2,0x087E,0x07F0,0x1803,0x17F2,0x0670,0x05FF,0x1372, //  344   AB8>AC0
     0x1BFF,0x1772,0x2910,0x087C,0x00F5,0x087D,0x00F6,0x0875, //  345   AC0>AC8
     0x39F0,0x1D03,0x2AD1,0x256A,0x00FE,0x3088,0x008A,0x087E, //  346   AC8>AD0
     0x2ADD,0x0876,0x0098,0x0875,0x38E0,0x0099,0x395F,0x0099, //  347   AD0>AD8
     0x0000,0x080D,0x1699,0x1799,0x00FE,0x087E,0x0670,0x3A80, //  348   AD8>AE0
     0x00FF,0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0,0x1803,0x17F2, //  349   AE0>AE8
     0x0670,0x05FF,0x1372,0x1BFF,0x1772,0x2910,0x0AF3,0x0FF4, //  350   AE8>AF0
     0x03F3,0x0873,0x39F0,0x1D03,0x2AFB,0x2565,0x00FB,0x3088, //  351   AF0>AF8
     0x008A,0x087B,0x2B07,0x0874,0x0098,0x0873,0x38E0,0x0099, //  352   AF8>B00
     0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x3A80, //  353   B00>B08
     0x1D03,0x2B0C,0x0871,0x00FB,0x0877,0x00FC,0x1BFB,0x03FC, //  354   B08>B10
     0x087B,0x0778,0x00FD,0x1803,0x0AFC,0x1BFB,0x2B42,0x0877, //  355   B10>B18
     0x39F0,0x1D03,0x2B21,0x256F,0x00FE,0x3088,0x008A,0x087E, //  356   B18>B20
     0x2B2D,0x0878,0x0098,0x0877,0x38E0,0x0099,0x395F,0x0099, //  357   B20>B28
     0x0000,0x080D,0x1699,0x1799,0x00FE,0x087C,0x00F7,0x087D, //  358   B28>B30
     0x00F8,0x087E,0x0670,0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2, //  359   B30>B38
     0x087E,0x07F0,0x1803,0x17F2,0x0670,0x05FF,0x1372,0x1BFF, //  360   B38>B40
     0x1772,0x2910,0x087C,0x00F7,0x087D,0x00F8,0x0877,0x39F0, //  361   B40>B48
     0x1D03,0x2B50,0x256F,0x00FE,0x3088,0x008A,0x087E,0x2B5C, //  362   B48>B50
     0x0878,0x0098,0x0877,0x38E0,0x0099,0x395F,0x0099,0x0000, //  363   B50>B58
     0x080D,0x1699,0x1799,0x00FE,0x087E,0x0670,0x3A80,0x00FF, //  364   B58>B60
     0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0,0x1803,0x17F2,0x0670, //  365   B60>B68
     0x05FF,0x1372,0x1BFF,0x1772,0x2910,0x0AF3,0x0FF4,0x03F3, //  366   B68>B70
     0x0873,0x39F0,0x1D03,0x2B7A,0x2565,0x00FB,0x3088,0x008A, //  367   B70>B78
     0x087B,0x2B86,0x0874,0x0098,0x0873,0x38E0,0x0099,0x395F, //  368   B78>B80
     0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x3A80,0x1D03, //  369   B80>B88
     0x2B8B,0x0871,0x00FB,0x0879,0x00FC,0x1BFB,0x03FC,0x087B, //  370   B88>B90
     0x077A,0x00FD,0x1803,0x0AFC,0x1BFB,0x2BC1,0x0879,0x39F0, //  371   B90>B98
     0x1D03,0x2BA0,0x2574,0x00FE,0x3088,0x008A,0x087E,0x2BAC, //  372   B98>BA0
     0x087A,0x0098,0x0879,0x38E0,0x0099,0x395F,0x0099,0x0000, //  373   BA0>BA8
     0x080D,0x1699,0x1799,0x00FE,0x087C,0x00F9,0x087D,0x00FA, //  374   BA8>BB0
     0x087E,0x0670,0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2,0x087E, //  375   BB0>BB8
     0x07F0,0x1803,0x17F2,0x0670,0x05FF,0x1372,0x1BFF,0x1772, //  376   BB8>BC0
     0x2910,0x087C,0x00F9,0x087D,0x00FA,0x0879,0x39F0,0x1D03, //  377   BC0>BC8
     0x2BCF,0x2574,0x00FE,0x3088,0x008A,0x087E,0x2BDB,0x087A, //  378   BC8>BD0
     0x0098,0x0879,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  379   BD0>BD8
     0x1699,0x1799,0x00FE,0x087E,0x0670,0x3A80,0x00FF,0x1BF2, //  380   BD8>BE0
     0x0FF0,0x13F2,0x087E,0x07F0,0x1803,0x17F2,0x0670,0x05FF, //  381   BE0>BE8
     0x1372,0x1BFF,0x1772,0x2910,0x0AF3,0x0FF4,0x03F3,0x0873, //  382   BE8>BF0
     0x39F0,0x1D03,0x2BF9,0x2565,0x00FB,0x3088,0x008A,0x087B, //  383   BF0>BF8
     0x2C05,0x0874,0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099, //  384   BF8>C00
     0x0000,0x080D,0x1699,0x1799,0x00FB,0x3A80,0x1D03,0x2C0A, //  385   C00>C08
     0x0871,0x00FB,0x0875,0x00FC,0x1BFB,0x03FC,0x087B,0x0776, //  386   C08>C10
     0x00FD,0x1803,0x0AFC,0x1BFB,0x2C31,0x0875,0x39F0,0x1D03, //  387   C10>C18
     0x2C1F,0x256A,0x00FE,0x3088,0x008A,0x087E,0x2C2B,0x0876, //  388   C18>C20
     0x0098,0x0875,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  389   C20>C28
     0x1699,0x1799,0x00FE,0x087C,0x00F5,0x087D,0x00F6,0x087E, //  390   C28>C30
     0x2C4B,0x087C,0x00F5,0x087D,0x00F6,0x0875,0x39F0,0x1D03, //  391   C30>C38
     0x2C3F,0x256A,0x00FE,0x3088,0x008A,0x087E,0x2C4B,0x0876, //  392   C38>C40
     0x0098,0x0875,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  393   C40>C48
     0x1699,0x1799,0x00FE,0x09FE,0x087E,0x0670,0x3A80,0x00FF, //  394   C48>C50
     0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0,0x1803,0x17F2,0x0670, //  395   C50>C58
     0x05FF,0x1372,0x1BFF,0x1772,0x2910,0x0AF3,0x0FF4,0x03F3, //  396   C58>C60
     0x0873,0x39F0,0x1D03,0x2C6A,0x2565,0x00FB,0x3088,0x008A, //  397   C60>C68
     0x087B,0x2C76,0x0874,0x0098,0x0873,0x38E0,0x0099,0x395F, //  398   C68>C70
     0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x3A80,0x1D03, //  399   C70>C78
     0x2C7B,0x0871,0x00FB,0x0877,0x00FC,0x1BFB,0x03FC,0x087B, //  400   C78>C80
     0x0778,0x00FD,0x1803,0x0AFC,0x1BFB,0x2CA2,0x0877,0x39F0, //  401   C80>C88
     0x1D03,0x2C90,0x256F,0x00FE,0x3088,0x008A,0x087E,0x2C9C, //  402   C88>C90
     0x0878,0x0098,0x0877,0x38E0,0x0099,0x395F,0x0099,0x0000, //  403   C90>C98
     0x080D,0x1699,0x1799,0x00FE,0x087C,0x00F7,0x087D,0x00F8, //  404   C98>CA0
     0x087E,0x2CBC,0x087C,0x00F7,0x087D,0x00F8,0x0877,0x39F0, //  405   CA0>CA8
     0x1D03,0x2CB0,0x256F,0x00FE,0x3088,0x008A,0x087E,0x2CBC, //  406   CA8>CB0
     0x0878,0x0098,0x0877,0x38E0,0x0099,0x395F,0x0099,0x0000, //  407   CB0>CB8
     0x080D,0x1699,0x1799,0x00FE,0x09FE,0x087E,0x0670,0x3A80, //  408   CB8>CC0
     0x00FF,0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0,0x1803,0x17F2, //  409   CC0>CC8
     0x0670,0x05FF,0x1372,0x1BFF,0x1772,0x2910,0x0AF3,0x0FF4, //  410   CC8>CD0
     0x03F3,0x0873,0x39F0,0x1D03,0x2CDB,0x2565,0x00FB,0x3088, //  411   CD0>CD8
     0x008A,0x087B,0x2CE7,0x0874,0x0098,0x0873,0x38E0,0x0099, //  412   CD8>CE0
     0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x3A80, //  413   CE0>CE8
     0x1D03,0x2CEC,0x0871,0x00FB,0x0879,0x00FC,0x1BFB,0x03FC, //  414   CE8>CF0
     0x087B,0x077A,0x00FD,0x1803,0x0AFC,0x1BFB,0x2D13,0x0879, //  415   CF0>CF8
     0x39F0,0x1D03,0x2D01,0x2574,0x00FE,0x3088,0x008A,0x087E, //  416   CF8>D00
     0x2D0D,0x087A,0x0098,0x0879,0x38E0,0x0099,0x395F,0x0099, //  417   D00>D08
     0x0000,0x080D,0x1699,0x1799,0x00FE,0x087C,0x00F9,0x087D, //  418   D08>D10
     0x00FA,0x087E,0x2D2D,0x087C,0x00F9,0x087D,0x00FA,0x0879, //  419   D10>D18
     0x39F0,0x1D03,0x2D21,0x2574,0x00FE,0x3088,0x008A,0x087E, //  420   D18>D20
     0x2D2D,0x087A,0x0098,0x0879,0x38E0,0x0099,0x395F,0x0099, //  421   D20>D28
     0x0000,0x080D,0x1699,0x1799,0x00FE,0x09FE,0x087E,0x0670, //  422   D28>D30
     0x3A80,0x00FF,0x1BF2,0x0FF0,0x13F2,0x087E,0x07F0,0x1803, //  423   D30>D38
     0x17F2,0x0670,0x05FF,0x1372,0x1BFF,0x1772,0x2910,0x018A, //  424   D38>D40
     0x2C72,0x018A,0x2DB9,0x018A,0x2C5E,0x018A,0x2CFA,0x018A, //  425   D40>D48
     0x2CFF,0x018A,0x2D04,0x018A,0x2D09,0x018A,0x2D0E,0x018A, //  426   D48>D50
     0x2D47,0x018A,0x2D80,0x018A,0x2C63,0x018A,0x2C68,0x018A, //  427   D50>D58
     0x2C6D,0x018A,0x2C83,0x018A,0x2BBA,0x018A,0x2BCF,0x018A, //  428   D58>D60
     0x2BE4,0x018A,0x2BF9,0x018A,0x2C95,0x0873,0x3E90,0x008A, //  429   D60>D68
     0x0874,0x0082,0x0875,0x3E90,0x008A,0x0876,0x0082,0x0877, //  430   D68>D70
     0x3E90,0x008A,0x0878,0x0082,0x0879,0x3E90,0x008A,0x087A, //  431   D70>D78
     0x0082,0x087C,0x3E90,0x008A,0x087D,0x0082,0x0AF3,0x0FF4, //  432   D78>D80
     0x03F3,0x0873,0x39F0,0x1D03,0x2D8B,0x2565,0x00FB,0x3008, //  433   D80>D88
     0x008A,0x087B,0x2D97,0x0874,0x0098,0x0873,0x38E0,0x0099, //  434   D88>D90
     0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x3A80, //  435   D90>D98
     0x1D03,0x2DA4,0x0873,0x00F3,0x1BF1,0x03F3,0x0871,0x0774, //  436   D98>DA0
     0x00F4,0x1803,0x0AF3,0x2910,0x0873,0x00F3,0x1BFB,0x03F3, //  437   DA0>DA8
     0x087B,0x0774,0x00F4,0x1803,0x0AF3,0x2910,0x0AF3,0x0FF4, //  438   DA8>DB0
     0x03F3,0x0873,0x39F0,0x1D03,0x2DBB,0x2565,0x00FB,0x3008, //  439   DB0>DB8
     0x008A,0x087B,0x2DC7,0x0874,0x0098,0x0873,0x38E0,0x0099, //  440   DB8>DC0
     0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x3A80, //  441   DC0>DC8
     0x1D03,0x2DD4,0x0875,0x00F3,0x1BF1,0x03F3,0x0871,0x0776, //  442   DC8>DD0
     0x00F4,0x1803,0x0AF3,0x2910,0x0875,0x00F3,0x1BFB,0x03F3, //  443   DD0>DD8
     0x087B,0x0776,0x00F4,0x1803,0x0AF3,0x2910,0x0AF3,0x0FF4, //  444   DD8>DE0
     0x03F3,0x0873,0x39F0,0x1D03,0x2DEB,0x2565,0x00FB,0x3008, //  445   DE0>DE8
     0x008A,0x087B,0x2DF7,0x0874,0x0098,0x0873,0x38E0,0x0099, //  446   DE8>DF0
     0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x3A80, //  447   DF0>DF8
     0x1D03,0x2E04,0x0877,0x00F3,0x1BF1,0x03F3,0x0871,0x0778, //  448   DF8>E00
     0x00F4,0x1803,0x0AF3,0x2910,0x0877,0x00F3,0x1BFB,0x03F3, //  449   E00>E08
     0x087B,0x0778,0x00F4,0x1803,0x0AF3,0x2910,0x0AF3,0x0FF4, //  450   E08>E10
     0x03F3,0x0873,0x39F0,0x1D03,0x2E1B,0x2565,0x00FB,0x3008, //  451   E10>E18
     0x008A,0x087B,0x2E27,0x0874,0x0098,0x0873,0x38E0,0x0099, //  452   E18>E20
     0x395F,0x0099,0x0000,0x080D,0x1699,0x1799,0x00FB,0x3A80, //  453   E20>E28
     0x1D03,0x2E34,0x0879,0x00F3,0x1BF1,0x03F3,0x0871,0x077A, //  454   E28>E30
     0x00F4,0x1803,0x0AF3,0x2910,0x0879,0x00F3,0x1BFB,0x03F3, //  455   E30>E38
     0x087B,0x077A,0x00F4,0x1803,0x0AF3,0x2910,0x0AF3,0x0FF4, //  456   E38>E40
     0x03F3,0x2910,0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0,0x1D03, //  457   E40>E48
     0x2E4F,0x2565,0x00FB,0x3088,0x008A,0x087B,0x2E5B,0x0874, //  458   E48>E50
     0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  459   E50>E58
     0x1699,0x1799,0x00FB,0x3A80,0x1D03,0x2E60,0x0871,0x00FB, //  460   E58>E60
     0x0875,0x00FC,0x1BFB,0x03FC,0x087B,0x0776,0x00FD,0x1803, //  461   E60>E68
     0x0AFC,0x1BFB,0x2E87,0x0875,0x39F0,0x1D03,0x2E75,0x256A, //  462   E68>E70
     0x00FE,0x3088,0x008A,0x087E,0x2E81,0x0876,0x0098,0x0875, //  463   E70>E78
     0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D,0x1699,0x1799, //  464   E78>E80
     0x00FE,0x087C,0x00F5,0x087D,0x00F6,0x087E,0x2EA1,0x087C, //  465   E80>E88
     0x00F5,0x087D,0x00F6,0x0875,0x39F0,0x1D03,0x2E95,0x256A, //  466   E88>E90
     0x00FE,0x3088,0x008A,0x087E,0x2EA1,0x0876,0x0098,0x0875, //  467   E90>E98
     0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D,0x1699,0x1799, //  468   E98>EA0
     0x00FE,0x0008,0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0,0x1D03, //  469   EA0>EA8
     0x2EAF,0x2565,0x00FB,0x3088,0x008A,0x087B,0x2EBB,0x0874, //  470   EA8>EB0
     0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  471   EB0>EB8
     0x1699,0x1799,0x00FB,0x3A80,0x1D03,0x2EC0,0x0871,0x00FB, //  472   EB8>EC0
     0x0877,0x00FC,0x1BFB,0x03FC,0x087B,0x0778,0x00FD,0x1803, //  473   EC0>EC8
     0x0AFC,0x1BFB,0x2EE7,0x0877,0x39F0,0x1D03,0x2ED5,0x256F, //  474   EC8>ED0
     0x00FE,0x3088,0x008A,0x087E,0x2EE1,0x0878,0x0098,0x0877, //  475   ED0>ED8
     0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D,0x1699,0x1799, //  476   ED8>EE0
     0x00FE,0x087C,0x00F7,0x087D,0x00F8,0x087E,0x2F01,0x087C, //  477   EE0>EE8
     0x00F7,0x087D,0x00F8,0x0877,0x39F0,0x1D03,0x2EF5,0x256F, //  478   EE8>EF0
     0x00FE,0x3088,0x008A,0x087E,0x2F01,0x0878,0x0098,0x0877, //  479   EF0>EF8
     0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D,0x1699,0x1799, //  480   EF8>F00
     0x00FE,0x0008,0x0AF3,0x0FF4,0x03F3,0x0873,0x39F0,0x1D03, //  481   F00>F08
     0x2F0F,0x2565,0x00FB,0x3088,0x008A,0x087B,0x2F1B,0x0874, //  482   F08>F10
     0x0098,0x0873,0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D, //  483   F10>F18
     0x1699,0x1799,0x00FB,0x3A80,0x1D03,0x2F20,0x0871,0x00FB, //  484   F18>F20
     0x0879,0x00FC,0x1BFB,0x03FC,0x087B,0x077A,0x00FD,0x1803, //  485   F20>F28
     0x0AFC,0x1BFB,0x2F47,0x0879,0x39F0,0x1D03,0x2F35,0x2574, //  486   F28>F30
     0x00FE,0x3088,0x008A,0x087E,0x2F41,0x087A,0x0098,0x0879, //  487   F30>F38
     0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D,0x1699,0x1799, //  488   F38>F40
     0x00FE,0x087C,0x00F9,0x087D,0x00FA,0x087E,0x2F61,0x087C, //  489   F40>F48
     0x00F9,0x087D,0x00FA,0x0879,0x39F0,0x1D03,0x2F55,0x2574, //  490   F48>F50
     0x00FE,0x3088,0x008A,0x087E,0x2F61,0x087A,0x0098,0x0879, //  491   F50>F58
     0x38E0,0x0099,0x395F,0x0099,0x0000,0x080D,0x1699,0x1799, //  492   F58>F60
     0x00FE,0x0008,0x3066,0x07FE,0x1BF2,0x0AF0,0x0DF2,0x087E, //  493   F60>F68
     0x07F0,0x0CF2,0x3006,0x1C83,0x02F0,0x3060,0x1FF2,0x02F0, //  494   F68>F70
     0x0008,0x018A,0x2828,0x018A,0x29D5,0x018A,0x29BB,0x018A, //  495   F70>F78
     0x2A0F,0xFFB7,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF, //  496   F78>F80
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  497   F80>F88
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  498   F88>F90
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  499   F90>F98
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  500   F98>FA0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  501   FA0>FA8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  502   FA8>FB0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  503   FB0>FB8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  504   FB8>FC0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  505   FC0>FC8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  506   FC8>FD0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  507   FD0>FD8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  508   FD8>FE0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  509   FE0>FE8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  510   FE8>FF0
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  511   FF0>FF8
     0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34,0xFF34, //  512   FF8>1000
     
// NO CHANGES BELOW HERE, SECTION ABOVE IS SC/MP ENGINE  ^^^ 512 LINES OF 8 WORDS

     0x3408,0x34C4,0x3410,0x3436,0x34C4,0x341C,0x3432,0x34C4,  // 1000 NIBL
     0x3411,0x3435,0x34C4,0x3420,0x3431,0x34C4,0x34FF,0x34C9,  // 1008
     0x3400,0x34C9,0x3401,0x34C4,0x340D,0x34C9,0x34FF,0x34C4,  // 1010
     0x3402,0x34CA,0x34F6,0x3431,0x34C4,0x3420,0x3435,0x34B9,  // 1018
     0x3402,0x3401,0x34C1,0x3480,0x34E4,0x340D,0x3498,0x3402,  // 1020
     0x34BA,0x34F6,0x34C4,0x3420,0x3435,0x34C4,0x34FF,0x34C9,  // 1028
     0x3400,0x34C9,0x3401,0x34C4,0x340D,0x34C9,0x34FF,0x3435,  // 1030
     0x3402,0x34F4,0x3410,0x34E4,0x3430,0x3498,0x3404,0x34E4,  // 1038
     0x3480,0x3490,0x34E9,0x34C4,0x3400,0x34CA,0x34F4,0x34CA,  // 1040
     0x34F5,0x34C4,0x3458,0x34CA,0x34FB,0x34C4,0x340C,0x34CA,  // 1048
     0x34FA,0x34C4,0x3400,0x34CA,0x34EA,0x3401,0x34C4,0x3400,  // 1050
     0x34CA,0x3480,0x34AA,0x34EA,0x3401,0x34C4,0x3434,0x3460,  // 1058
     0x349C,0x34F4,0x34C4,0x3450,0x34CA,0x34FD,0x34C4,0x347A,  // 1060
     0x34CA,0x34FF,0x34C4,0x346A,0x34CA,0x34FC,0x34C4,0x34A6,  // 1068
     0x34CA,0x34F9,0x34C4,0x348A,0x34CA,0x34FE,0x34C2,0x34FB,  // 1070
     0x3433,0x34C2,0x34FA,0x3437,0x34C7,0x3401,0x3401,0x34C7,  // 1078
     0x3401,0x3433,0x34CA,0x34FB,0x3440,0x34D4,0x340F,0x34DC,  // 1080
     0x3400,0x3437,0x34CA,0x34FA,0x3440,0x34D4,0x34F0,0x34E4,  // 1088
     0x3420,0x3498,0x342F,0x34E4,0x34A0,0x3498,0x3407,0x34E4,  // 1090
     0x34C0,0x3498,0x34E1,0x343F,0x3490,0x34D8,0x34C2,0x34F9,  // 1098
     0x34E4,0x34D6,0x349C,0x3404,0x34C4,0x340A,0x3490,0x3460,  // 10A0
     0x34E4,0x34D6,0x3433,0x34CA,0x34EA,0x34C4,0x3410,0x3437,  // 10A8
     0x3401,0x34C2,0x34FB,0x34CF,0x3401,0x34C2,0x34FA,0x34CF,  // 10B0
     0x3401,0x34C2,0x34EA,0x3433,0x34CA,0x34F9,0x3440,0x3437,  // 10B8
     0x3490,0x34BA,0x34CA,0x34E7,0x34C5,0x3401,0x34E4,0x3420,  // 10C0
     0x3498,0x34FA,0x34C5,0x34FF,0x34C2,0x34FA,0x3437,0x34CA,  // 10C8
     0x34EC,0x34C2,0x34FB,0x3433,0x34CA,0x34ED,0x34C7,0x3401,  // 10D0
     0x3401,0x34BA,0x34E7,0x3440,0x34D4,0x347F,0x34E5,0x3401,  // 10D8
     0x349C,0x3407,0x3440,0x3494,0x34F1,0x3490,0x3495,0x3490,  // 10E0
     0x348D,0x34C2,0x34E7,0x3401,0x34C5,0x3480,0x34C2,0x34ED,  // 10E8
     0x3433,0x34C2,0x34EC,0x3437,0x3490,0x34CA,0x34C4,0x3410,  // 10F0
     0x3437,0x34C2,0x34F9,0x3433,0x34C7,0x34FF,0x3401,0x34C7,  // 10F8
     0x34FF,0x3433,0x34CA,0x34F9,0x3440,0x3437,0x3490,0x34B8,  // 1100
     0x3490,0x3441,0x34C2,0x34FC,0x34E4,0x347A,0x3498,0x341C,  // 1108
     0x34AA,0x34FC,0x34AA,0x34FC,0x3433,0x34C4,0x3410,0x3437,  // 1110
     0x34C2,0x34F4,0x3498,0x340A,0x3435,0x34CB,0x34FF,0x3435,  // 1118
     0x3431,0x34CB,0x34FE,0x3431,0x3490,0x34C1,0x34C4,0x34FF,  // 1120
     0x34CB,0x34FF,0x3490,0x34BB,0x34C4,0x340A,0x3490,0x341B,  // 1128
     0x34C5,0x3401,0x34E4,0x3420,0x3498,0x34FA,0x34E4,0x342D,  // 1130
     0x3498,0x3404,0x34E4,0x3437,0x349C,0x3401,0x343F,0x34C4,  // 1138
     0x3404,0x3490,0x3408,0x34C2,0x34FC,0x34E4,0x346A,0x349C,  // 1140
     0x3404,0x34C4,0x3409,0x3490,0x3440,0x34BA,0x34FC,0x34BA,  // 1148
     0x34FC,0x3433,0x34C4,0x3410,0x3437,0x34C3,0x3401,0x3494,  // 1150
     0x3406,0x34C4,0x3400,0x34CA,0x34F4,0x3490,0x3488,0x3435,  // 1158
     0x34C3,0x3400,0x3431,0x34C4,0x3401,0x34CA,0x34F4,0x3490,  // 1160
     0x34F4,0x34C2,0x34F2,0x3494,0x3404,0x34C4,0x3408,0x3490,  // 1168
     0x341C,0x34C4,0x3401,0x34CA,0x34F4,0x343F,0x34C4,0x340F,  // 1170
     0x3437,0x34C4,0x34C1,0x3433,0x34C5,0x3401,0x34E4,0x3422,  // 1178
     0x3498,0x34DB,0x34E4,0x342F,0x3498,0x3405,0x34E4,0x340D,  // 1180
     0x343F,0x3490,0x34EB,0x34C4,0x3407,0x3490,0x3435,0x34C4,  // 1188
     0x3410,0x3437,0x34AA,0x34FD,0x34AA,0x34FD,0x3433,0x34C4,  // 1190
     0x340A,0x34CB,0x34FE,0x34C4,0x3400,0x34CB,0x34FF,0x34C4,  // 1198
     0x3405,0x34CA,0x34E7,0x34C4,0x34FF,0x34CB,0x3405,0x34C3,  // 11A0
     0x34FD,0x3494,0x3413,0x34C4,0x342D,0x34CB,0x3404,0x34C4,  // 11A8
     0x3400,0x3403,0x34FB,0x34FC,0x34CB,0x34FC,0x34C4,0x3400,  // 11B0
     0x34FB,0x34FD,0x34CB,0x34FD,0x3490,0x349F,0x34C4,0x3420,  // 11B8
     0x34CB,0x3404,0x3490,0x3499,0x3490,0x3457,0x34AA,0x34FD,  // 11C0
     0x34AA,0x34FD,0x3431,0x34C4,0x3410,0x3435,0x34AA,0x34E7,  // 11C8
     0x3401,0x34C1,0x3401,0x34DC,0x3430,0x34C9,0x3480,0x34C1,  // 11D0
     0x34FD,0x34D9,0x34FC,0x3498,0x340A,0x34C4,0x340F,0x34CA,  // 11D8
     0x34FA,0x34C4,0x3433,0x34CA,0x34FB,0x3490,0x34DB,0x34C4,  // 11E0
     0x340F,0x3437,0x34C4,0x34C1,0x3433,0x34C2,0x34F5,0x349C,  // 11E8
     0x3406,0x34C1,0x3404,0x343F,0x34C2,0x34E7,0x3401,0x34C5,  // 11F0
     0x3480,0x34C1,0x3400,0x343F,0x34C5,0x34FF,0x3494,0x34FB,  // 11F8
     0x34C4,0x3450,0x34CA,0x34FD,0x34C2,0x34F5,0x349C,0x34BA,  // 1200
     0x34C4,0x3420,0x343F,0x3490,0x34B5,0x34C4,0x340F,0x3437,  // 1208
     0x34C4,0x34C1,0x3433,0x34C4,0x340D,0x343F,0x34C4,0x340A,  // 1210
     0x343F,0x3490,0x34A7,0x34C4,0x3405,0x34CA,0x34EB,0x34C2,  // 1218
     0x34EB,0x34CA,0x34EA,0x34C4,0x340F,0x3437,0x34C4,0x34C1,  // 1220
     0x3433,0x34C4,0x340D,0x343F,0x34C4,0x340A,0x343F,0x34C4,  // 1228
     0x340F,0x3435,0x34C4,0x343B,0x3431,0x34BA,0x34EB,0x3498,  // 1230
     0x3406,0x34C5,0x3401,0x3494,0x34FC,0x3490,0x34F6,0x34C5,  // 1238
     0x3401,0x343F,0x34C1,0x34FF,0x3494,0x34F9,0x34C2,0x34EA,  // 1240
     0x34E4,0x340E,0x3498,0x340D,0x34C4,0x340F,0x3435,0x34C4,  // 1248
     0x343B,0x3431,0x34C5,0x3401,0x343F,0x34C1,0x34FF,0x3494,  // 1250
     0x34F9,0x34C2,0x34F4,0x3498,0x344D,0x34C4,0x3420,0x343F,  // 1258
     0x34C4,0x3441,0x343F,0x34C4,0x3454,0x343F,0x34C4,0x3410,  // 1260
     0x3437,0x34AA,0x34FD,0x34AA,0x34FD,0x3433,0x34C2,0x34F7,  // 1268
     0x34CB,0x34FF,0x34C2,0x34F8,0x34CB,0x34FE,0x34C4,0x3431,  // 1270
     0x34CA,0x34FB,0x34C4,0x340E,0x34CA,0x34FA,0x3490,0x3499,  // 1278
     0x34C4,0x340E,0x3490,0x3499,0x34C2,0x34F4,0x3498,0x3422,  // 1280
     0x34C1,0x3400,0x34D4,0x3480,0x349C,0x341C,0x3422,0x34D4,  // 1288
     0x3420,0x3498,0x34ED,0x34C1,0x34FF,0x34E4,0x340D,0x349C,  // 1290
     0x3408,0x34C5,0x3401,0x34CA,0x34F7,0x34C5,0x3402,0x34CA,  // 1298
     0x34F8,0x34C4,0x340C,0x34CA,0x34FA,0x34C4,0x3486,0x34CA,  // 12A0
     0x34FB,0x343F,0x34C4,0x3400,0x34CA,0x34F4,0x34C4,0x3450,  // 12A8
     0x34CA,0x34FD,0x34C4,0x341C,0x34CA,0x34FB,0x34C4,0x340C,  // 12B0
     0x34CA,0x34FA,0x34C4,0x34A6,0x34CA,0x34F9,0x3490,0x34BE,  // 12B8
     0x34AA,0x34F4,0x34C2,0x34E9,0x3435,0x34C2,0x34E8,0x3431,  // 12C0
     0x34C4,0x346A,0x34CA,0x34FC,0x34C4,0x348A,0x34CA,0x34FE,  // 12C8
     0x34C4,0x347A,0x34CA,0x34FF,0x343F,0x3490,0x34A7,0x3490,  // 12D0
     0x34A9,0x34C1,0x3400,0x34E4,0x3480,0x3494,0x3418,0x34C4,  // 12D8
     0x3410,0x3437,0x34AA,0x34FD,0x34AA,0x34FD,0x3433,0x34C5,  // 12E0
     0x3401,0x34CB,0x34FF,0x34C5,0x3401,0x34CB,0x34FE,0x34C5,  // 12E8
     0x3401,0x34C4,0x3401,0x34CA,0x34F5,0x3490,0x34DE,0x34C4,  // 12F0
     0x3400,0x34CA,0x34F5,0x34C4,0x3402,0x3437,0x34C4,0x3483,  // 12F8
     0x3433,0x343F,0x3490,0x34D1,0x3490,0x34D1,0x34C4,0x340F,  // 1300
     0x3437,0x34C4,0x34C1,0x3433,0x3422,0x34D4,0x3420,0x3498,  // 1308
     0x34E6,0x34C5,0x3401,0x34E4,0x340D,0x3498,0x3405,0x34E4,  // 1310
     0x340D,0x343F,0x3490,0x34F0,0x34C4,0x340D,0x343F,0x34C4,  // 1318
     0x340A,0x343F,0x3402,0x34C4,0x344B,0x34CA,0x34FB,0x34C4,  // 1320
     0x340C,0x34CA,0x34FA,0x3490,0x34AC,0x34C4,0x3410,0x3437,  // 1328
     0x34BA,0x34FD,0x34BA,0x34FD,0x3433,0x3402,0x34C3,0x34FE,  // 1330
     0x34F3,0x3400,0x34CB,0x34FE,0x34C3,0x34FF,0x34F3,0x3401,  // 1338
     0x34CB,0x34FF,0x3490,0x34BE,0x34C4,0x3410,0x3437,0x34BA,  // 1340
     0x34FD,0x34BA,0x34FD,0x3433,0x3403,0x34C3,0x34FE,0x34FB,  // 1348
     0x3400,0x34CB,0x34FE,0x34C3,0x34FF,0x34FB,0x3401,0x34CB,  // 1350
     0x34FF,0x3490,0x34A7,0x34C4,0x3410,0x3437,0x34C2,0x34FD,  // 1358
     0x3433,0x3403,0x34C4,0x3400,0x34FB,0x34FE,0x34CB,0x34FE,  // 1360
     0x34C4,0x3400,0x34FB,0x34FF,0x34CB,0x34FF,0x3490,0x34D2,  // 1368
     0x3490,0x3492,0x34C4,0x3410,0x3437,0x34C2,0x34FD,0x3433,  // 1370
     0x34C3,0x34FF,0x34E3,0x34FD,0x34CA,0x34EA,0x34C3,0x34FF,  // 1378
     0x3494,0x340D,0x3403,0x34C4,0x3400,0x34FB,0x34FE,0x34CB,  // 1380
     0x34FE,0x34C4,0x3400,0x34FB,0x34FF,0x34CB,0x34FF,0x34C3,  // 1388
     0x34FD,0x3494,0x340D,0x3403,0x34C4,0x3400,0x34FB,0x34FC,  // 1390
     0x34CB,0x34FC,0x34C4,0x3400,0x34FB,0x34FD,0x34CB,0x34FD,  // 1398
     0x34C4,0x3400,0x34CB,0x3400,0x34CB,0x3401,0x34CB,0x3402,  // 13A0
     0x34CB,0x3403,0x34C4,0x3410,0x34CA,0x34EB,0x34C3,0x34FF,  // 13A8
     0x341F,0x34CB,0x34FF,0x34C3,0x34FE,0x341F,0x34CB,0x34FE,  // 13B0
     0x3406,0x3494,0x3411,0x3402,0x34C3,0x3402,0x34F3,0x34FC,  // 13B8
     0x34CB,0x3402,0x34C3,0x3403,0x34F3,0x34FD,0x34CB,0x3403,  // 13C0
     0x3490,0x3402,0x3490,0x34A4,0x3402,0x34C3,0x3403,0x341F,  // 13C8
     0x34CB,0x3403,0x34C3,0x3402,0x341F,0x34CB,0x3402,0x34C3,  // 13D0
     0x3401,0x341F,0x34CB,0x3401,0x34C3,0x3400,0x341F,0x34CB,  // 13D8
     0x3400,0x34BA,0x34EB,0x349C,0x34C9,0x3490,0x3402,0x3490,  // 13E0
     0x3485,0x34C2,0x34EA,0x3494,0x340D,0x3403,0x34C4,0x3400,  // 13E8
     0x34FB,0x3400,0x34CB,0x3400,0x34C4,0x3400,0x34FB,0x3401,  // 13F0
     0x34CB,0x3401,0x34C3,0x3400,0x34CB,0x34FC,0x34C3,0x3401,  // 13F8
     0x34CB,0x34FD,0x34BA,0x34FD,0x34BA,0x34FD,0x3490,0x34DF,  // 1400
     0x34C4,0x3410,0x3437,0x34C2,0x34FD,0x3433,0x34C3,0x34FF,  // 1408
     0x34DB,0x34FE,0x349C,0x3404,0x34C4,0x340D,0x3490,0x34B2,  // 1410
     0x34C3,0x34FD,0x34E3,0x34FF,0x34CA,0x34EA,0x34C3,0x34FD,  // 1418
     0x3494,0x3411,0x34C4,0x3400,0x3403,0x34FB,0x34FC,0x34CB,  // 1420
     0x3403,0x34C4,0x3400,0x34FB,0x34FD,0x34CB,0x3402,0x3490,  // 1428
     0x340A,0x3490,0x34B4,0x34C3,0x34FD,0x34CB,0x3402,0x34C3,  // 1430
     0x34FC,0x34CB,0x3403,0x34C3,0x34FF,0x3494,0x340D,0x34C4,  // 1438
     0x3400,0x3403,0x34FB,0x34FE,0x34CB,0x34FE,0x34C4,0x3400,  // 1440
     0x34FB,0x34FF,0x34CB,0x34FF,0x34C4,0x3400,0x34CB,0x3401,  // 1448
     0x34CB,0x3400,0x34CA,0x34EB,0x34CB,0x34FD,0x34CB,0x34FC,  // 1450
     0x3402,0x34C3,0x34FC,0x34F3,0x34FC,0x34CB,0x34FC,0x34C3,  // 1458
     0x34FD,0x34F3,0x34FD,0x34CB,0x34FD,0x3402,0x34C3,0x3403,  // 1460
     0x34F3,0x3403,0x34CB,0x3403,0x34C3,0x3402,0x34F3,0x3402,  // 1468
     0x34CB,0x3402,0x34C3,0x3401,0x34F3,0x3401,0x34CB,0x3401,  // 1470
     0x34C3,0x3400,0x34F3,0x3400,0x34CB,0x3400,0x3403,0x34C3,  // 1478
     0x3401,0x34FB,0x34FE,0x34CB,0x3401,0x34C3,0x3400,0x34FB,  // 1480
     0x34FF,0x34CB,0x3400,0x3494,0x3411,0x3402,0x34C3,0x3401,  // 1488
     0x34F3,0x34FE,0x34CB,0x3401,0x34C3,0x3400,0x34F3,0x34FF,  // 1490
     0x34CB,0x3400,0x3490,0x3408,0x3490,0x3493,0x34C3,0x34FC,  // 1498
     0x34DC,0x3401,0x34CB,0x34FC,0x34AA,0x34EB,0x34E4,0x3410,  // 14A0
     0x349C,0x34AE,0x34C2,0x34EA,0x3494,0x340D,0x34C4,0x3400,  // 14A8
     0x3403,0x34FB,0x34FC,0x34CB,0x34FC,0x34C4,0x3400,0x34FB,  // 14B0
     0x34FD,0x34CB,0x34FD,0x34BA,0x34FD,0x34BA,0x34FD,0x3490,  // 14B8
     0x34DB,0x34C4,0x3410,0x3437,0x34C2,0x34FD,0x3433,0x34C7,  // 14C0
     0x34FD,0x3401,0x34C3,0x3401,0x34CA,0x3480,0x3402,0x3440,  // 14C8
     0x34F4,0x3401,0x3401,0x34C3,0x3402,0x34CA,0x3480,0x3433,  // 14D0
     0x34CA,0x34FD,0x34C4,0x3400,0x3437,0x34C4,0x3475,0x3433,  // 14D8
     0x343F,0x34C5,0x3401,0x34E4,0x3420,0x3498,0x34FA,0x34C1,  // 14E0
     0x34FF,0x3403,0x34FC,0x345B,0x3494,0x3405,0x3403,0x34FC,  // 14E8
     0x34E6,0x3494,0x3412,0x34C5,0x34FF,0x34C2,0x34FB,0x3433,  // 14F0
     0x34C2,0x34FA,0x3437,0x34C3,0x3400,0x34CA,0x34FA,0x34C3,  // 14F8
     0x3401,0x34CA,0x34FB,0x3490,0x34D5,0x3401,0x34C1,0x3400,  // 1500
     0x3403,0x34FC,0x345B,0x3494,0x3405,0x3403,0x34FC,0x34E6,  // 1508
     0x3494,0x34E1,0x34C4,0x3410,0x3437,0x34AA,0x34FD,0x3433,  // 1510
     0x3402,0x3440,0x3470,0x34CB,0x34FF,0x34C4,0x3402,0x3402,  // 1518
     0x34F2,0x34FB,0x34CA,0x34FB,0x34C4,0x3400,0x34F2,0x34FA,  // 1520
     0x34CA,0x34FA,0x3490,0x34AE,0x34C4,0x3410,0x3437,0x34AA,  // 1528
     0x34FD,0x3433,0x34C3,0x34FE,0x3401,0x34C2,0x3480,0x34CB,  // 1530
     0x34FE,0x3402,0x3440,0x34F4,0x3401,0x3401,0x34C2,0x3480,  // 1538
     0x34CB,0x34FF,0x3490,0x3496,0x34C4,0x3401,0x3490,0x3412,  // 1540
     0x34C4,0x3402,0x3490,0x340E,0x34C4,0x3403,0x3490,0x340A,  // 1548
     0x34C4,0x3404,0x3490,0x3406,0x34C4,0x3405,0x3490,0x3402,  // 1550
     0x34C4,0x3406,0x34CA,0x34EB,0x34C4,0x3410,0x3437,0x34BA,  // 1558
     0x34FD,0x34BA,0x34FD,0x3433,0x3403,0x34C3,0x34FE,0x34FB,  // 1560
     0x3400,0x34CA,0x34EF,0x34C3,0x34FF,0x34FB,0x3401,0x34CA,  // 1568
     0x34EE,0x34E3,0x34FF,0x3401,0x34C3,0x34FF,0x34E3,0x3401,  // 1570
     0x3450,0x34E2,0x34EE,0x34CA,0x34EA,0x34C2,0x34EE,0x34DA,  // 1578
     0x34EF,0x3498,0x3402,0x34C4,0x3480,0x34E4,0x3480,0x3401,  // 1580
     0x34BA,0x34EB,0x349C,0x3405,0x3440,0x3490,0x342B,0x3490,  // 1588
     0x34B1,0x34BA,0x34EB,0x349C,0x3405,0x3440,0x34E4,0x3480,  // 1590
     0x3490,0x3420,0x34BA,0x34EB,0x349C,0x3404,0x34C2,0x34EA,  // 1598
     0x3490,0x3418,0x34BA,0x34EB,0x349C,0x3405,0x3440,0x34DA,  // 15A0
     0x34EA,0x3490,0x340F,0x34BA,0x34EB,0x349C,0x3407,0x3440,  // 15A8
     0x34DA,0x34EA,0x34E4,0x3480,0x3490,0x3404,0x34C2,0x34EA,  // 15B0
     0x34E4,0x3480,0x3494,0x3404,0x34C4,0x3401,0x3490,0x3402,  // 15B8
     0x34C4,0x3400,0x34CB,0x34FE,0x34C4,0x3400,0x34CB,0x34FF,  // 15C0
     0x34C4,0x3400,0x3437,0x34C4,0x34F5,0x3433,0x343F,0x3490,  // 15C8
     0x34BE,0x34C2,0x34EF,0x34DA,0x34EE,0x3498,0x3402,0x3490,  // 15D0
     0x34B6,0x34C5,0x3401,0x34E4,0x340D,0x349C,0x34FA,0x34C4,  // 15D8
     0x3402,0x3437,0x34C4,0x3483,0x3433,0x343F,0x3490,0x34A7,  // 15E0
     0x34C4,0x3401,0x3490,0x3406,0x34C4,0x3402,0x3490,0x3402,  // 15E8
     0x34C4,0x3403,0x34CA,0x34EB,0x34C4,0x3410,0x3437,0x34BA,  // 15F0
     0x34FD,0x34BA,0x34FD,0x3433,0x34BA,0x34EB,0x349C,0x340E,  // 15F8
     0x34C3,0x3401,0x34D3,0x34FF,0x34CB,0x34FF,0x34C3,0x3400,  // 1600
     0x34D3,0x34FE,0x34CB,0x34FE,0x3490,0x34D8,0x34BA,0x34EB,  // 1608
     0x349C,0x340E,0x34C3,0x3401,0x34DB,0x34FF,0x34CB,0x34FF,  // 1610
     0x34C3,0x3400,0x34DB,0x34FE,0x34CB,0x34FE,0x3490,0x34C6,  // 1618
     0x34C7,0x3401,0x34E4,0x34FF,0x34CB,0x34FF,0x34C7,0x3401,  // 1620
     0x34E4,0x34FF,0x34CB,0x34FF,0x3433,0x34CA,0x34FD,0x3490,  // 1628
     0x34B5,0x34C2,0x34F1,0x3431,0x34CA,0x34F1,0x34C2,0x34F0,  // 1630
     0x3435,0x34CA,0x34F0,0x343F,0x34C2,0x34F4,0x3498,0x3401,  // 1638
     0x343F,0x34C4,0x3403,0x34CA,0x34EB,0x34C4,0x3402,0x3437,  // 1640
     0x34C4,0x341E,0x3433,0x343F,0x34AA,0x34FD,0x34AA,0x34FD,  // 1648
     0x3433,0x34C4,0x3410,0x3437,0x34C4,0x3400,0x34CB,0x34FF,  // 1650
     0x34CB,0x34FE,0x34CA,0x34EB,0x34C5,0x3401,0x34E4,0x3420,  // 1658
     0x3498,0x34FA,0x34C5,0x34FF,0x34C1,0x3400,0x3403,0x34FC,  // 1660
     0x343A,0x3494,0x3409,0x3403,0x34FC,0x34F6,0x3494,0x3413,  // 1668
     0x3490,0x3432,0x3490,0x34BB,0x3403,0x34FC,0x340D,0x3494,  // 1670
     0x342B,0x3403,0x34FC,0x34FA,0x3494,0x3402,0x3490,0x3424,  // 1678
     0x3402,0x34F4,0x340A,0x3401,0x34C4,0x3404,0x34CA,0x34EA,  // 1680
     0x34CA,0x34EB,0x34C3,0x34FE,0x3402,0x34F3,0x34FE,0x34CB,  // 1688
     0x34FE,0x34C3,0x34FF,0x34F3,0x34FF,0x34CB,0x34FF,0x34BA,  // 1690
     0x34EA,0x349C,0x34EF,0x34C3,0x34FE,0x3458,0x34CB,0x34FE,  // 1698
     0x34C5,0x3401,0x3490,0x34C0,0x34C2,0x34EB,0x349C,0x3487,  // 16A0
     0x34C4,0x3405,0x3490,0x3497,0x34C5,0x3401,0x34E4,0x3420,  // 16A8
     0x3498,0x34FA,0x34C5,0x34FF,0x3403,0x34FC,0x343A,0x3494,  // 16B0
     0x3405,0x3403,0x34FC,0x34F6,0x3494,0x3421,0x34C2,0x34FB,  // 16B8
     0x3433,0x34C2,0x34FA,0x3437,0x34C3,0x3400,0x34CA,0x34FA,  // 16C0
     0x34C3,0x3401,0x34CA,0x34FB,0x3490,0x34A4,0x34C4,0x3402,  // 16C8
     0x3402,0x34F2,0x34FB,0x34CA,0x34FB,0x34C4,0x3400,0x34F2,  // 16D0
     0x34FA,0x34CA,0x34FA,0x3490,0x3495,0x3490,0x34CB,0x3401,  // 16D8
     0x34C4,0x3410,0x3437,0x34AA,0x34FD,0x34AA,0x34FD,0x3433,  // 16E0
     0x34C4,0x3400,0x34CB,0x34FF,0x3440,0x34CB,0x34FE,0x34C5,  // 16E8
     0x3401,0x34C1,0x3400,0x3403,0x34FC,0x343A,0x3494,0x34D6,  // 16F0
     0x3403,0x34FC,0x34F6,0x3494,0x3402,0x3490,0x34CF,0x3401,  // 16F8
     0x34C3,0x34FF,0x34CB,0x3401,0x34C3,0x34FE,0x34CB,0x3400,  // 1700
     0x34C4,0x3402,0x34CA,0x34EA,0x3402,0x34C3,0x34FE,0x34F3,  // 1708
     0x34FE,0x34CB,0x34FE,0x34C3,0x34FF,0x34F3,0x34FF,0x34CB,  // 1710
     0x34FF,0x34D4,0x3480,0x349C,0x3434,0x34BA,0x34EA,0x349C,  // 1718
     0x34EB,0x3402,0x34C3,0x34FE,0x34F3,0x3400,0x34CB,0x34FE,  // 1720
     0x34C3,0x34FF,0x34F3,0x3401,0x34CB,0x34FF,0x34D4,0x3480,  // 1728
     0x349C,0x341F,0x3402,0x34C3,0x34FE,0x34F3,0x34FE,0x34CB,  // 1730
     0x34FE,0x34C3,0x34FF,0x34F3,0x34FF,0x34CB,0x34FF,0x34D4,  // 1738
     0x3480,0x349C,0x340E,0x3402,0x3440,0x34F3,0x34FE,0x34CB,  // 1740
     0x34FE,0x34C4,0x3400,0x34F3,0x34FF,0x34CB,0x34FF,0x3494,  // 1748
     0x349E,0x34C4,0x3406,0x3490,0x3488,0x3490,0x3484,0x34C4,  // 1750
     0x3410,0x3435,0x34C4,0x34D6,0x3431,0x34C4,0x3400,0x34CA,  // 1758
     0x34E7,0x34C4,0x340F,0x3437,0x34C4,0x34C1,0x3433,0x34C2,  // 1760
     0x34F4,0x3498,0x3408,0x34C4,0x343F,0x343F,0x34C4,0x3420,  // 1768
     0x343F,0x3490,0x3403,0x34C4,0x343E,0x343F,0x34C4,0x340F,  // 1770
     0x3437,0x34C4,0x3476,0x3433,0x343F,0x34C4,0x34C1,0x3433,  // 1778
     0x3440,0x3498,0x34F3,0x34E4,0x340A,0x3498,0x34EF,0x3440,  // 1780
     0x34E4,0x340D,0x3498,0x3450,0x3440,0x34E4,0x345F,0x3498,  // 1788
     0x3441,0x3440,0x34E4,0x3408,0x3498,0x3436,0x3440,0x34E4,  // 1790
     0x3415,0x3498,0x340F,0x3440,0x34E4,0x3403,0x349C,0x341A,  // 1798
     0x34C4,0x345E,0x343F,0x34C4,0x3443,0x343F,0x34C4,0x340E,  // 17A0
     0x3490,0x34A9,0x34C4,0x345E,0x343F,0x34C4,0x3455,0x343F,  // 17A8
     0x34C4,0x340D,0x343F,0x34C4,0x340A,0x343F,0x3490,0x349F,  // 17B0
     0x3490,0x349B,0x3440,0x34CD,0x3401,0x34AA,0x34E7,0x34E4,  // 17B8
     0x3448,0x349C,0x34B3,0x34C4,0x340D,0x3401,0x3440,0x343F,  // 17C0
     0x3490,0x3412,0x3490,0x3487,0x34C4,0x3420,0x343F,0x34C4,  // 17C8
     0x3408,0x343F,0x34C2,0x34E7,0x3498,0x34A0,0x34BA,0x34E7,  // 17D0
     0x34C5,0x34FF,0x3490,0x349A,0x3440,0x34CD,0x3401,0x34C4,  // 17D8
     0x340A,0x343F,0x34C4,0x3410,0x3435,0x34C4,0x34D6,0x3431,  // 17E0
     0x3490,0x34CE,0x34C4,0x3410,0x3437,0x34C2,0x34FD,0x3433,  // 17E8
     0x34C3,0x34FF,0x3435,0x3401,0x34C3,0x34FE,0x3431,0x34CA,  // 17F0
     0x34EF,0x34C1,0x3400,0x34CB,0x34FE,0x34C4,0x3400,0x34CB,  // 17F8
     0x34FF,0x34C2,0x34EF,0x3431,0x3440,0x3435,0x3490,0x34B0,  // 1800
     0x34C4,0x3410,0x3437,0x34C2,0x34FD,0x3433,0x34C7,0x34FE,  // 1808
     0x3401,0x34C7,0x34FF,0x34CA,0x34EA,0x34C7,0x34FF,0x3433,  // 1810
     0x34CA,0x34FD,0x34C2,0x34EA,0x3437,0x3440,0x34CB,0x3400,  // 1818
     0x3490,0x34C6,0x3490,0x34A6,0x34C4,0x3410,0x3437,0x34C2,  // 1820
     0x34FD,0x3433,0x34C3,0x3401,0x34CA,0x34F7,0x34C3,0x3400,  // 1828
     0x34CA,0x34F8,0x34C2,0x34F1,0x3433,0x34C2,0x34F0,0x3437,  // 1830
     0x34C4,0x3404,0x34CA,0x34E7,0x34C7,0x3401,0x34E4,0x340D,  // 1838
     0x3498,0x3404,0x34AA,0x34E7,0x3490,0x34F6,0x34C2,0x34E7,  // 1840
     0x34E4,0x3404,0x349C,0x3402,0x34CA,0x34E7,0x34C2,0x34E7,  // 1848
     0x3401,0x34C2,0x34F2,0x3494,0x3406,0x34D4,0x347F,0x34CA,  // 1850
     0x34F2,0x3490,0x3418,0x34C5,0x3403,0x3440,0x3402,0x34F4,  // 1858
     0x34FC,0x3401,0x34C5,0x3401,0x34E4,0x340D,0x3498,0x340B,  // 1860
     0x3440,0x3402,0x34F4,0x34FF,0x3401,0x3490,0x34F3,0x3490,  // 1868
     0x34AF,0x3490,0x34AF,0x3440,0x34DA,0x34E7,0x3498,0x34F7,  // 1870
     0x34C4,0x347A,0x34CA,0x34FF,0x34C4,0x346A,0x34CA,0x34FC,  // 1878
     0x34C4,0x348A,0x34CA,0x34FE,0x3440,0x3498,0x3460,0x3494,  // 1880
     0x3410,0x34C1,0x3400,0x34C9,0x3480,0x34C5,0x3401,0x3494,  // 1888
     0x34F8,0x34C1,0x3400,0x3494,0x34F4,0x34C9,0x3480,0x3490,  // 1890
     0x344E,0x34C1,0x34FE,0x34CA,0x34EA,0x34C4,0x34FF,0x34C9,  // 1898
     0x34FE,0x34C4,0x3450,0x34C9,0x34FF,0x34C5,0x3401,0x3494,  // 18A0
     0x34FC,0x34C1,0x3400,0x3494,0x34F8,0x3435,0x34CA,0x34EE,  // 18A8
     0x3435,0x3431,0x34CA,0x34EF,0x3431,0x34C2,0x34EF,0x3402,  // 18B0
     0x3470,0x34C4,0x3400,0x34F2,0x34EE,0x34E2,0x34EE,0x34D4,  // 18B8
     0x34F0,0x3498,0x3403,0x34C4,0x3400,0x3401,0x34C4,0x34FF,  // 18C0
     0x34C9,0x3480,0x34C5,0x34FF,0x3494,0x34FA,0x34C1,0x3401,  // 18C8
     0x34E4,0x3450,0x3498,0x3404,0x34C1,0x3400,0x3490,0x34F0,  // 18D0
     0x34C2,0x34EA,0x34C9,0x3400,0x34C4,0x340D,0x34C9,0x3401,  // 18D8
     0x3440,0x349C,0x3404,0x34C4,0x3402,0x3490,0x348A,0x34C2,  // 18E0
     0x34E7,0x3498,0x3484,0x34C2,0x34F1,0x3431,0x34C2,0x34F0,  // 18E8
     0x3435,0x34C2,0x34F3,0x3433,0x34C2,0x34F2,0x3437,0x34C2,  // 18F0
     0x34F7,0x34CF,0x3401,0x34C2,0x34F8,0x34CF,0x3401,0x34C2,  // 18F8
     0x34E7,0x34CF,0x3401,0x34C5,0x3401,0x34CF,0x3401,0x34E4,  // 1900
     0x340D,0x349C,0x34F8,0x3490,0x34DC,0x34C4,0x3400,0x3437,  // 1908
     0x34C4,0x3475,0x3433,0x343F,0x3490,0x34CF,0x34BA,0x34FD,  // 1910
     0x34BA,0x34FD,0x3433,0x34C4,0x3410,0x3437,0x34C3,0x3400,  // 1918
     0x34CA,0x34EF,0x34C3,0x3401,0x34CA,0x34EE,0x3490,0x34E5,  // 1920
     0x34C2,0x34FF,0x3401,0x3440,0x34E4,0x347A,0x349C,0x3404,  // 1928
     0x34C4,0x340F,0x3490,0x34E0,0x34C2,0x34EF,0x34DA,0x34EE,  // 1930
     0x3498,0x3406,0x34BA,0x34FF,0x34BA,0x34FF,0x3490,0x34CD,  // 1938
     0x3440,0x3433,0x34C4,0x3410,0x3437,0x34C3,0x34FF,0x3435,  // 1940
     0x34C3,0x34FE,0x3431,0x3490,0x34C0,0x34C2,0x34EF,0x34D4,  // 1948
     0x34FF,0x3407,0x3490,0x34B9,0x3490,0x34BE,0x34C4,0x3410,  // 1950
     0x3437,0x34AA,0x34FD,0x34AA,0x34FD,0x3433,0x3406,0x34CB,  // 1958
     0x34FE,0x34C4,0x3400,0x34CB,0x34FF,0x3490,0x34EB,0x34C2,  // 1960
     0x34EE,0x3437,0x34C2,0x34EF,0x3433,0x34C7,0x34FF,0x343F,  // 1968
     0x34C4,0x3410,0x3436,0x34C4,0x341C,0x3432,0x3490,0x34DA,  // 1970
     0x34C2,0x34FF,0x34E4,0x348A,0x349C,0x3404,0x34C4,0x340A,  // 1978
     0x3490,0x34D2,0x34AA,0x34FF,0x34AA,0x34FF,0x3433,0x34C4,  // 1980
     0x3410,0x3437,0x3435,0x34CB,0x34FF,0x3435,0x3431,0x34CB,  // 1988
     0x34FE,0x3431,0x3490,0x34BE,0x34C2,0x34E9,0x3437,0x34C2,  // 1990
     0x34E8,0x3433,0x34C3,0x3400,0x3494,0x3402,0x3490,0x3407,  // 1998
     0x34C3,0x3402,0x3401,0x34C7,0x3480,0x3490,0x34F3,0x34C7,  // 19A0
     0x3402,0x34AA,0x34FD,0x34AA,0x34FD,0x3433,0x3401,0x34C4,  // 19A8
     0x3410,0x3437,0x34CB,0x34FF,0x3440,0x34CB,0x34FE,0x3490,  // 19B0
     0x34D9,0x34C5,0x3401,0x34E4,0x340D,0x349C,0x34FA,0x343F,  // 19B8
     0x34C2,0x34FD,0x3433,0x34C4,0x3410,0x3437,0x34C3,0x3403,  // 19C0
     0x34CB,0x34FE,0x34C3,0x3402,0x34CB,0x34FF,0x3490,0x34C2,  // 19C8
     0x3490,0x34AE,0x34C4,0x3408,0x34CA,0x34EB,0x34C2,0x34E5,  // 19D0
     0x3401,0x34C2,0x34E4,0x34CA,0x34E9,0x34C2,0x34E5,0x3402,  // 19D8
     0x3470,0x3401,0x34C2,0x34E4,0x3402,0x34F2,0x34E9,0x34CA,  // 19E0
     0x34E4,0x34BA,0x34EB,0x349C,0x34F0,0x3440,0x3402,0x34F4,  // 19E8
     0x3407,0x3401,0x34C2,0x34E4,0x3402,0x34F4,0x3407,0x341E,  // 19F0
     0x34CA,0x34E4,0x34AA,0x34E6,0x3498,0x3403,0x3440,0x34CA,  // 19F8
     0x34E5,0x34C2,0x34FD,0x3433,0x34C4,0x3410,0x3437,0x34C4,  // 1A00
     0x3401,0x34CB,0x3400,0x34C4,0x3400,0x34CB,0x3401,0x34C3,  // 1A08
     0x34FE,0x34CB,0x3402,0x34C3,0x34FF,0x34CB,0x3403,0x34C3,  // 1A10
     0x34FC,0x34CB,0x3404,0x34C3,0x34FD,0x34CB,0x3405,0x34C2,  // 1A18
     0x34E4,0x34CB,0x34FE,0x34C2,0x34E5,0x34E4,0x34FF,0x34D4,  // 1A20
     0x347F,0x34CB,0x34FF,0x34C7,0x3406,0x3433,0x34CA,0x34FD,  // 1A28
     0x3490,0x349C,0x3490,0x349C,0x34AA,0x34FD,0x34AA,0x34FD,  // 1A30
     0x3433,0x34C4,0x3410,0x3437,0x34C4,0x3400,0x34CB,0x34FF,  // 1A38
     0x34C4,0x3401,0x34CB,0x34FE,0x3490,0x34EA,0x34C2,0x34FE,  // 1A40
     0x34E4,0x34A6,0x349C,0x3404,0x34C4,0x340A,0x3490,0x34E2,  // 1A48
     0x34E4,0x34A6,0x3431,0x34CA,0x34F1,0x34C4,0x3410,0x3435,  // 1A50
     0x34CA,0x34F0,0x34C2,0x34FD,0x3433,0x34C4,0x3410,0x3437,  // 1A58
     0x34C3,0x34F9,0x34CD,0x3401,0x34C3,0x34FC,0x34CD,0x3401,  // 1A60
     0x34C3,0x34FD,0x34CD,0x3401,0x34C3,0x34FE,0x34CD,0x3401,  // 1A68
     0x34C3,0x34FF,0x34CD,0x3401,0x34C2,0x34F1,0x34CD,0x3401,  // 1A70
     0x34C2,0x34F0,0x34CD,0x3401,0x3435,0x34C2,0x34F1,0x3431,  // 1A78
     0x34CA,0x34FE,0x34C7,0x34FC,0x3433,0x34CA,0x34FD,0x3490,  // 1A80
     0x34A7,0x34C2,0x34FE,0x34E4,0x348A,0x349C,0x3404,0x34C4,  // 1A88
     0x340B,0x3490,0x34BB,0x34E4,0x348A,0x3431,0x34CA,0x34F1,  // 1A90
     0x34C4,0x3410,0x3435,0x34CA,0x34F0,0x34C2,0x34FD,0x3433,  // 1A98
     0x34C4,0x3410,0x3437,0x34C7,0x34FF,0x34E1,0x34F9,0x3498,  // 1AA0
     0x3404,0x34C4,0x340C,0x3490,0x34A1,0x34E1,0x34F9,0x3401,  // 1AA8
     0x34C2,0x3480,0x3402,0x34F1,0x34FC,0x34CA,0x3480,0x34CB,  // 1AB0
     0x3400,0x34C6,0x3401,0x34C2,0x3480,0x34F1,0x34FD,0x34CA,  // 1AB8
     0x3480,0x34CB,0x3401,0x34C6,0x34FF,0x34C1,0x34FA,0x34CB,  // 1AC0
     0x3402,0x34C1,0x34FB,0x34CB,0x3403,0x34C1,0x34FD,0x3494,  // 1AC8
     0x3410,0x34C4,0x3404,0x34CA,0x34EB,0x34C7,0x3401,0x34E4,  // 1AD0
     0x34FF,0x34CB,0x34FF,0x34BA,0x34EB,0x349C,0x34F6,0x3490,  // 1AD8
     0x3402,0x34C7,0x3404,0x3433,0x34CA,0x34FD,0x34C2,0x34F1,  // 1AE0
     0x3431,0x34C2,0x34F0,0x3435,0x3490,0x3499,0x34C2,0x34EF,  // 1AE8
     0x3498,0x3408,0x34C2,0x34FE,0x3402,0x34F4,0x34F9,0x34CA,  // 1AF0
     0x34FE,0x343F,0x34C2,0x34FE,0x3433,0x34C4,0x3410,0x3437,  // 1AF8
     0x34C3,0x34FF,0x3435,0x34C3,0x34FE,0x3431,0x3490,0x34E4,  // 1B00
     0x3490,0x34A1,0x34C2,0x34EE,0x3435,0x34C2,0x34EF,0x3431,  // 1B08
     0x34C4,0x340F,0x3437,0x34C4,0x34C1,0x3433,0x34C5,0x3401,  // 1B10
     0x34E4,0x340D,0x3498,0x34D0,0x34E4,0x340D,0x343F,0x3422,  // 1B18
     0x34D4,0x3420,0x349C,0x34F2,0x3490,0x34C6,0x34C2,0x34EE,  // 1B20
     0x3437,0x34C2,0x34EF,0x3433,0x34C5,0x3401,0x34CF,0x3401,  // 1B28
     0x34E4,0x340D,0x349C,0x34F8,0x3490,0x34B6,0x34C2,0x34EF,  // 1B30
     0x3433,0x34C2,0x34EE,0x3437,0x34C5,0x3401,0x34E4,0x3422,  // 1B38
     0x3498,0x340E,0x34E4,0x342F,0x349C,0x3404,0x34C4,0x3407,  // 1B40
     0x3490,0x34BE,0x34E4,0x340D,0x34CF,0x3401,0x3490,0x34EC,  // 1B48
     0x34C4,0x340D,0x34CB,0x3400,0x3490,0x34DE,0x34C2,0x34FD,  // 1B50
     0x3433,0x34C4,0x3410,0x3437,0x34C7,0x34FF,0x3435,0x34C7,  // 1B58
     0x34FF,0x3431,0x34C7,0x34FF,0x3401,0x34C7,0x34FF,0x3433,  // 1B60
     0x34CA,0x34FD,0x3440,0x3437,0x34C5,0x3401,0x34CF,0x3401,  // 1B68
     0x34E4,0x340D,0x3498,0x34C0,0x3422,0x34D4,0x3420,0x349C,  // 1B70
     0x34F3,0x3490,0x34B9,0x34AA,0x34FD,0x34AA,0x34FD,0x3433,  // 1B78
     0x34C4,0x3410,0x3437,0x34C2,0x34F6,0x34CB,0x34FE,0x34C4,  // 1B80
     0x3400,0x34CB,0x34FF,0x3490,0x34A7,0x34C2,0x34EF,0x34D4,  // 1B88
     0x3407,0x349C,0x3402,0x34C4,0x3401,0x34CA,0x34F6,0x343F,  // 1B90
     0x34C2,0x34F6,0x34E4,0x3401,0x349C,0x3409,0x34C4,0x3411,  // 1B98
     0x34CA,0x34E9,0x34C4,0x3420,0x34CA,0x34E8,0x343F,0x34E4,  // 1BA0
     0x3401,0x3401,0x34C4,0x3404,0x34CA,0x34EB,0x3440,0x3402,  // 1BA8
     0x3470,0x3401,0x34BA,0x34EB,0x349C,0x34F8,0x3440,0x34CA,  // 1BB0
     0x34E9,0x34C4,0x3402,0x34CA,0x34E8,0x343F,0x34C2,0x34E9,  // 1BB8
     0x3435,0x34C2,0x34E8,0x3431,0x343F,0x3435,0x3401,0x3440,  // 1BC0
     0x3435,0x3440,0x341C,0x341C,0x341C,0x341C,0x34CA,0x34F6,  // 1BC8
     0x343F,0x34C2,0x34E9,0x3435,0x34C2,0x34E8,0x3431,0x34C4,  // 1BD0
     0x340D,0x34C9,0x34FF,0x34C4,0x34FF,0x34C9,0x3400,0x34C9,  // 1BD8
     0x3401,0x343F,0x34C2,0x34E9,0x3435,0x34C2,0x34E8,0x3431,  // 1BE0
     0x34C1,0x3400,0x34E4,0x34FF,0x3494,0x3412,0x3403,0x34C1,  // 1BE8
     0x3401,0x34FA,0x34EF,0x34C1,0x3400,0x34FA,0x34EE,0x3494,  // 1BF0
     0x3407,0x34C1,0x3402,0x3401,0x34C5,0x3480,0x3490,0x34E8,  // 1BF8
     0x3431,0x34CA,0x34F3,0x3431,0x3435,0x34CA,0x34F2,0x3435,  // 1C00
     0x34C2,0x34EF,0x34E1,0x3401,0x349C,0x3407,0x34C2,0x34EE,  // 1C08
     0x34E1,0x3400,0x349C,0x3401,0x343F,0x34C2,0x34F2,0x34DC,  // 1C10
     0x3480,0x34CA,0x34F2,0x343F,0x3402,0x340C,0x3407,0x3456,  // 1C18
     0x342C,0x3425,0x348D,0x344C,0x341E,0x3406,0x34AB,0x340C,  // 1C20
     0x3435,0x340B,0x3497,0x3406,0x3430,0x3409,0x3415,0x340B,  // 1C28
     0x34E1,0x3408,0x3423,0x344C,0x341E,0x342C,0x3451,0x344C,  // 1C30
     0x3449,0x3453,0x34D4,0x340B,0x3497,0x3406,0x34AB,0x340C,  // 1C38
     0x3447,0x3409,0x3415,0x340B,0x34E1,0x344C,0x3449,0x340B,  // 1C40
     0x34BD,0x3402,0x34D8,0x348F,0x342F,0x3403,0x3405,0x344C,  // 1C48
     0x341C,0x342C,0x3460,0x3452,0x3455,0x34CE,0x3401,0x342F,  // 1C50
     0x340B,0x3497,0x340B,0x34BD,0x3402,0x34BF,0x3402,0x3483,  // 1C58
     0x342C,0x346D,0x3443,0x344C,0x3445,0x3441,0x34D2,0x3401,  // 1C60
     0x342F,0x3400,0x3450,0x3402,0x3483,0x342C,0x3486,0x344E,  // 1C68
     0x3445,0x34D7,0x3406,0x34AB,0x340C,0x3478,0x344C,0x347A,  // 1C70
     0x340A,0x3433,0x3401,0x342F,0x3409,0x3415,0x340B,0x348C,  // 1C78
     0x340B,0x3497,0x340B,0x34D0,0x3402,0x3483,0x342C,0x348B,  // 1C80
     0x344C,0x3445,0x34D4,0x3404,0x34E0,0x340C,0x349A,0x342E,  // 1C88
     0x342F,0x34BD,0x348E,0x3435,0x3404,0x34C0,0x3401,0x342F,  // 1C90
     0x3402,0x3483,0x342C,0x34AA,0x34C0,0x348E,0x34AC,0x342E,  // 1C98
     0x342F,0x34BD,0x348E,0x3435,0x3408,0x3407,0x3401,0x342F,  // 1CA0
     0x3402,0x3483,0x342C,0x34BC,0x3449,0x34C6,0x348E,0x3435,  // 1CA8
     0x342C,0x34B6,0x3454,0x3448,0x3445,0x34CE,0x3409,0x3415,  // 1CB0
     0x3405,0x34D0,0x344C,0x3486,0x342C,0x34D1,0x3455,0x344E,  // 1CB8
     0x3454,0x3449,0x34CC,0x3406,0x343B,0x348E,0x3435,0x3401,  // 1CC0
     0x342F,0x3409,0x3415,0x3409,0x3427,0x340B,0x34C4,0x3402,  // 1CC8
     0x3483,0x342C,0x34DD,0x3444,0x34CF,0x3406,0x343B,0x3401,  // 1CD0
     0x342F,0x3409,0x3477,0x3402,0x3483,0x342D,0x3400,0x3447,  // 1CD8
     0x34CF,0x342C,0x34EB,0x3454,0x34CF,0x348E,0x3435,0x3401,  // 1CE0
     0x342F,0x344C,0x34F6,0x342E,0x342F,0x3453,0x3455,0x34C2,  // 1CE8
     0x348E,0x3435,0x3401,0x342F,0x3401,0x3409,0x340B,0x3497,  // 1CF0
     0x3409,0x3415,0x340B,0x34E1,0x3401,0x3468,0x3402,0x3483,  // 1CF8
     0x342D,0x3410,0x3452,0x3445,0x3454,0x3455,0x3452,0x34CE,  // 1D00
     0x3401,0x342F,0x3401,0x3442,0x340B,0x34C4,0x3402,0x3483,  // 1D08
     0x342D,0x342A,0x344E,0x3445,0x3458,0x34D4,0x3406,0x343B,  // 1D10
     0x3404,0x34E0,0x340E,0x342F,0x3401,0x342F,0x340A,0x3488,  // 1D18
     0x348E,0x345F,0x3409,0x3415,0x340A,0x34ED,0x340B,0x34C4,  // 1D20
     0x3402,0x3483,0x342D,0x3454,0x3446,0x344F,0x34D2,0x3406,  // 1D28
     0x343B,0x3404,0x34E0,0x340E,0x342F,0x342E,0x342F,0x34BD,  // 1D30
     0x348E,0x3435,0x342E,0x342F,0x3454,0x34CF,0x348E,0x3435,  // 1D38
     0x342D,0x344A,0x3453,0x3454,0x3445,0x34D0,0x348E,0x3435,  // 1D40
     0x344D,0x344C,0x340A,0x3433,0x3401,0x342F,0x340A,0x3445,  // 1D48
     0x3404,0x34C0,0x3402,0x3483,0x342D,0x3467,0x3453,0x3454,  // 1D50
     0x3441,0x34D4,0x342E,0x342F,0x34BD,0x348E,0x3435,0x3409,  // 1D58
     0x3415,0x3409,0x344C,0x3401,0x342F,0x3402,0x3483,0x342D,  // 1D60
     0x347E,0x3450,0x3441,0x3447,0x34C5,0x342E,0x342F,0x34BD,  // 1D68
     0x348E,0x3435,0x3401,0x342F,0x3409,0x3415,0x340B,0x348C,  // 1D70
     0x340B,0x3497,0x340B,0x34BD,0x3402,0x3483,0x342D,0x349E,  // 1D78
     0x34A4,0x348E,0x34AC,0x342E,0x342F,0x34BD,0x342D,0x348F,  // 1D80
     0x34A2,0x3409,0x3415,0x340B,0x3435,0x344D,0x349A,0x342E,  // 1D88
     0x342F,0x34A4,0x348E,0x34AC,0x3406,0x3430,0x340B,0x3455,  // 1D90
     0x3406,0x3430,0x3401,0x342F,0x3402,0x3483,0x342D,0x34D1,  // 1D98
     0x3450,0x34D2,0x342D,0x34A7,0x3449,0x344E,0x34D4,0x342D,  // 1DA0
     0x34AE,0x34A2,0x3401,0x3475,0x344D,0x34C1,0x342D,0x34BD,  // 1DA8
     0x34A4,0x348E,0x34AC,0x3406,0x3430,0x3409,0x3415,0x340B,  // 1DB0
     0x3409,0x3406,0x3430,0x344D,0x34C1,0x348E,0x3435,0x348F,  // 1DB8
     0x342F,0x342D,0x34C6,0x34AC,0x344D,0x34A7,0x342D,0x34CB,  // 1DC0
     0x34BB,0x344D,0x34CD,0x3402,0x340C,0x3401,0x342F,0x3402,  // 1DC8
     0x3483,0x342E,0x3409,0x3449,0x344E,0x3450,0x3455,0x34D4,  // 1DD0
     0x3406,0x343B,0x3404,0x34E0,0x340D,0x34F6,0x3406,0x3430,  // 1DD8
     0x3407,0x3456,0x348E,0x3435,0x3404,0x34C0,0x3406,0x3430,  // 1DE0
     0x342E,0x3405,0x34AC,0x3404,0x34E0,0x340E,0x342F,0x3406,  // 1DE8
     0x3430,0x342E,0x342F,0x34AC,0x344D,0x34E2,0x342E,0x342F,  // 1DF0
     0x34A4,0x348E,0x34AC,0x3406,0x3430,0x3407,0x3456,0x3409,  // 1DF8
     0x3415,0x340B,0x3425,0x3406,0x3430,0x3401,0x342F,0x3402,  // 1E00
     0x3483,0x342E,0x3412,0x3445,0x344E,0x34C4,0x3401,0x342F,  // 1E08
     0x3402,0x347F,0x342E,0x3426,0x344C,0x3449,0x344E,0x34CB,  // 1E10
     0x348E,0x3435,0x3401,0x342F,0x3406,0x3430,0x3409,0x3415,  // 1E18
     0x3409,0x3466,0x3406,0x3430,0x3402,0x3483,0x342E,0x342F,  // 1E20
     0x3452,0x3445,0x34CD,0x3409,0x34B8,0x3402,0x3483,0x3402,  // 1E28
     0x341A,0x348F,0x342F,0x3402,0x34A9,0x348E,0x3461,0x342E,  // 1E30
     0x343E,0x34BD,0x348E,0x3461,0x3405,0x3443,0x342E,0x3453,  // 1E38
     0x34BC,0x342E,0x3448,0x34BD,0x348E,0x3461,0x3405,0x344F,  // 1E40
     0x342E,0x344F,0x34BE,0x348E,0x3461,0x3405,0x3447,0x348E,  // 1E48
     0x3461,0x3405,0x344B,0x342E,0x348B,0x34BE,0x342E,0x345D,  // 1E50
     0x34BD,0x348E,0x3461,0x3405,0x3457,0x348E,0x3461,0x3405,  // 1E58
     0x3453,0x342E,0x346A,0x34AD,0x348E,0x348D,0x3403,0x345A,  // 1E60
     0x344E,0x346F,0x342E,0x346D,0x34AB,0x348E,0x348D,0x342E,  // 1E68
     0x3478,0x34AB,0x348E,0x348D,0x3403,0x342C,0x344E,0x346F,  // 1E70
     0x342E,0x3481,0x34AD,0x348E,0x348D,0x3403,0x3443,0x344E,  // 1E78
     0x346F,0x342E,0x348B,0x344F,0x34D2,0x348E,0x348D,0x3405,  // 1E80
     0x34EB,0x344E,0x346F,0x3400,0x34F5,0x348E,0x34AC,0x342E,  // 1E88
     0x3498,0x34AA,0x348E,0x34AC,0x3403,0x3471,0x344E,0x348F,  // 1E90
     0x342E,0x34A1,0x34AF,0x348E,0x34AC,0x3404,0x3407,0x344E,  // 1E98
     0x348F,0x342E,0x348B,0x3441,0x344E,0x34C4,0x348E,0x34AC,  // 1EA0
     0x3405,0x34E7,0x344E,0x348F,0x3404,0x34E0,0x340E,0x34B4,  // 1EA8
     0x3405,0x342B,0x3400,0x34F5,0x3406,0x34AB,0x340E,0x34BA,  // 1EB0
     0x3400,0x34F5,0x342E,0x34C1,0x34A3,0x3406,0x344B,0x3400,  // 1EB8
     0x34F5,0x342E,0x34CB,0x34A8,0x348E,0x3435,0x342E,0x342F,  // 1EC0
     0x34A9,0x3400,0x34F5,0x342E,0x34D4,0x34C0,0x348E,0x34AC,  // 1EC8
     0x3407,0x34E9,0x3400,0x34F5,0x342E,0x34DF,0x344E,0x344F,  // 1ED0
     0x34D4,0x348E,0x34AC,0x3405,0x34EF,0x3400,0x34F5,0x342E,  // 1ED8
     0x34E9,0x3453,0x3454,0x3441,0x34D4,0x3409,0x3455,0x3400,  // 1EE0
     0x34F5,0x342E,0x34F4,0x3454,0x344F,0x34D0,0x340B,0x3497,  // 1EE8
     0x3409,0x3493,0x3400,0x34F5,0x342F,0x3401,0x344D,0x344F,  // 1EF0
     0x34C4,0x348F,0x3420,0x3404,0x3407,0x3409,0x34BF,0x3400,  // 1EF8
     0x34F5,0x342F,0x3416,0x3452,0x344E,0x34C4,0x348F,0x3420,  // 1F00
     0x3409,0x34D1,0x3403,0x3443,0x3403,0x342C,0x3404,0x3407,  // 1F08
     0x3409,0x34BF,0x3403,0x342C,0x3400,0x34F5,0x342E,0x342F,  // 1F10
     0x3450,0x3441,0x3447,0x34C5,0x340B,0x347A,0x3400,0x34F5,  // 1F18
     0x342E,0x342F,0x34A8,0x348E,0x3435,0x342E,0x342F,0x34AC,  // 1F20
     0x348E,0x3435,0x342E,0x342F,0x34A9,0x3400,0x34F5,0x3406,  // 1F28
     0x3430,0x3401,0x348E,0x3404,0x3407,0x3401,0x34C5,0x3406,  // 1F30
     0x3430,0x3400,0x34F5,0x3420,0x3445,0x3452,0x3452,0x344F,  // 1F38
     0x34D2,0x3441,0x3452,0x3445,0x34C1,0x3453,0x3454,0x344D,  // 1F40
     0x34D4,0x3443,0x3448,0x3441,0x34D2,0x3453,0x344E,0x3454,  // 1F48
     0x34D8,0x3456,0x3441,0x344C,0x34D5,0x3445,0x344E,0x3444,  // 1F50
     0x34A2,0x344E,0x344F,0x3447,0x34CF,0x3452,0x3454,0x3452,  // 1F58
     0x34CE,0x344E,0x3445,0x3453,0x34D4,0x344E,0x3445,0x3458,  // 1F60
     0x34D4,0x3446,0x344F,0x34D2,0x3444,0x3449,0x3456,0x34B0,  // 1F68
     0x3442,0x3452,0x34CB,0x3455,0x344E,0x3454,0x34CC,0x3421,  // 1F70
     0x343F,0x3490,0x34FC,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1F78
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1F80
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1F88
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1F90
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1F98
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1FA0
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1FA8
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1FB0
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1FB8
     0x3400,0x3400,0x3420,0x343F,0x3490,0x34FC,0x3400,0x3400,  // 1FC0
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1FC8
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1FD0
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1FD8
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1FE0
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1FE8
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1FF0
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 1FF8
     0x34FF,0x34FF,0x34FF,0x34FF,0x3420,0x3411,0x3400,0x3404,  // 2100
     0x340E,0x348B,0x342C,0x3400,0x3410,0x34E0,0x3411,0x3485,  // 2108
     0x3400,0x3400,0x3402,0x3400,0x3482,0x34A6,0x340E,0x3422,  // 2110
     0x346A,0x3450,0x348A,0x347A,0x340D,0x3400,0x340D,0x3400,  // 2118
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 2120
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 2128
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 2130
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 2138
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 2140
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 2148
     0x3400,0x342C,0x340C,0x3400,0x3400,0x3401,0x3400,0x3400,  // 2150
     0x3420,0x34FF,0x3430,0x3433,0x3431,0x34FF,0x34FF,0x34FF,  // 2158
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 2160
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 2168
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 2170
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 2178
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 2180
     0x34FF,0x34FF,0x3400,0x340C,0x3400,0x3401,0x3400,0x3437,  // 2188
     0x3411,0x3402,0x340C,0x3400,0x3401,0x3400,0x3448,0x3411,  // 2190
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 2198
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x341A,0x340E,  // 21A0
     0x3437,0x340E,0x346F,0x340E,0x348F,0x340E,0x34FF,0x34FF,  // 21A8
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 21B0
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 21B8
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 21C0
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 21C8
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x344C,0x3449,  // 21D0
     0x344E,0x344B,0x3423,0x3432,0x3443,0x3430,0x3430,0x340D,  // 21D8
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 21E0
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 21E8
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 21F0
     0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,0x34FF,  // 21F8
   };
   const int pg0len = sizeof(pg0)/2;

   const uint16_t pg3[] PROGMEM = 
   { 0x34FF,0x340D,0x3400,0x3464,0x340C,0x3420,0x3450,0x3452,  // 3000
     0x3420,0x3450,0x3441,0x3447,0x3445,0x340D,0x34FF,0x34FF,  // 3008
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3010
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3018
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3020
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3028
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3030
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3038
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3040
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3048
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3050
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3058
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3060
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3068
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3070
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3078
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3080
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3088
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3090
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3098
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30A0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30A8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30B0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30B8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30C0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30C8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30D0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30D8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30E0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30E8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30F0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 30F8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3100
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3108
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3110
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3118
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3120
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3128
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3130
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3138
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3140
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3148
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3150
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3158
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3160
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3168
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3170
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3178
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3180
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3188
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3190
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3198
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31A0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31A8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31B0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31B8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31C0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31C8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31D0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31D8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31E0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31E8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31F0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 31F8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3200
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3208
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3210
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3218
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3220
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3228
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3230
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3238
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3240
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3248
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3250
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3258
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3260
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3268
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3270
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3278
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3280
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3288
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3290
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3298
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32A0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32A8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32B0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32B8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32C0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32C8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32D0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32D8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32E0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32E8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32F0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 32F8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3300
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3308
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3310
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3318
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3320
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3328
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3330
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3338
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3340
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3348
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3350
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3358
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3360
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3368
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3370
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3378
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3380
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3388
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3390
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3398
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33A0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33A8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33B0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33B8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33C0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33C8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33D0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33D8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33E0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33E8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33F0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 33F8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3400
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3408
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3410
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3418
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3420
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3428
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3430
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3438
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3440
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3448
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3450
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3458
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3460
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3468
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3470
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3478
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3480
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3488
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3490
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3498
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34A0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34A8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34B0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34B8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34C0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34C8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34D0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34D8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34E0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34E8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34F0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 34F8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3500
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3508
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3510
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3518
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3520
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3528
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3530
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3538
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3540
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3548
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3550
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3558
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3560
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3568
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3570
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3578
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3580
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3588
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3590
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3598
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35A0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35A8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35B0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35B8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35C0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35C8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35D0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35D8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35E0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35E8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35F0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 35F8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3600
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3608
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3610
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3618
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3620
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3628
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3630
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3638
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3640
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3648
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3650
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3658
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3660
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3668
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3670
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3678
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3680
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3688
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3690
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3698
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36A0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36A8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36B0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36B8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36C0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36C8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36D0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36D8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36E0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36E8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36F0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 36F8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3700
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3708
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3710
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3718
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3720
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3728
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3730
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3738
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3740
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3748
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3750
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3758
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3760
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3768
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3770
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3778
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3780
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3788
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3790
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3798
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37A0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37A8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37B0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37B8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37C0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37C8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37D0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37D8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37E0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37E8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37F0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 37F8
     0x3408,0x34C4,0x34E1,0x34C8,0x34FA,0x34C4,0x341D,0x3431,  // 3800
     0x34C4,0x3428,0x3435,0x34C5,0x3401,0x3401,0x3406,0x34D4,  // 3808
     0x34F0,0x3458,0x3407,0x34C4,0x34FF,0x348F,0x34C0,0x34B8,  // 3810
     0x34E6,0x349C,0x34F0,0x3490,0x34E4,0x3400,0x3408,0x3404,  // 3818
     0x3402,0x3401,0x3401,0x3402,0x3404,0x3408,0x3408,0x3404,  // 3820
     0x3402,0x3401,0x3401,0x3402,0x3404,0x3408,0x3408,0x3404,  // 3828
     0x3402,0x3401,0x3401,0x3402,0x3404,0x3408,0x3408,0x3404,  // 3830
     0x3402,0x3401,0x3401,0x3402,0x3404,0x3408,0x3400,0x3408,  // 3838
     0x340C,0x340E,0x340F,0x3407,0x3403,0x3401,0x3400,0x3401,  // 3840
     0x3403,0x3407,0x340F,0x340E,0x340C,0x3408,0x3400,0x3400,  // 3848
     0x3408,0x340C,0x340E,0x340F,0x3407,0x3403,0x3401,0x3400,  // 3850
     0x3401,0x3403,0x3407,0x340F,0x340E,0x340C,0x3408,0x3400,  // 3858
     0x3400,0x3408,0x340C,0x340E,0x340F,0x3407,0x3403,0x3401,  // 3860
     0x3400,0x3401,0x3403,0x3407,0x340F,0x340E,0x340C,0x3408,  // 3868
     0x3400,0x3400,0x3408,0x340C,0x340E,0x340F,0x3407,0x3403,  // 3870
     0x3401,0x3400,0x3401,0x3403,0x3407,0x340F,0x340E,0x340C,  // 3878
     0x3408,0x3400,0x3405,0x3405,0x3405,0x340A,0x340A,0x340A,  // 3880
     0x3405,0x3405,0x3405,0x340A,0x340A,0x340A,0x3405,0x3405,  // 3888
     0x3405,0x340A,0x340A,0x340A,0x3405,0x3405,0x340A,0x340A,  // 3890
     0x3405,0x3405,0x340A,0x340A,0x3405,0x3405,0x340A,0x340A,  // 3898
     0x3405,0x340A,0x3405,0x340A,0x3405,0x340A,0x3405,0x340A,  // 38A0
     0x3405,0x3400,0x3409,0x3409,0x3409,0x3409,0x340F,0x340F,  // 38A8
     0x3409,0x3409,0x3409,0x3409,0x340F,0x340F,0x3409,0x3409,  // 38B0
     0x3409,0x3409,0x340F,0x340F,0x3409,0x3409,0x3409,0x3409,  // 38B8
     0x3400,0x3406,0x3406,0x3406,0x3406,0x340F,0x340F,0x3406,  // 38C0
     0x3406,0x3406,0x3406,0x340F,0x340F,0x3406,0x3406,0x3406,  // 38C8
     0x3406,0x340F,0x340F,0x3400,0x3400,0x3400,0x3400,0x3400,  // 38D0
     0x3406,0x3406,0x3400,0x3406,0x3406,0x3400,0x3406,0x3406,  // 38D8
     0x3400,0x3406,0x3406,0x3400,0x3406,0x3406,0x3400,0x3406,  // 38E0
     0x3406,0x3400,0x3400,0x3409,0x3409,0x3400,0x3409,0x3409,  // 38E8
     0x3400,0x3409,0x3409,0x3400,0x3409,0x3409,0x3400,0x3409,  // 38F0
     0x3409,0x3400,0x3409,0x3409,0x3400,0x3400,0x3400,0x3FFF,  // 38F8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3900
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3908
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3910
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3918
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3920
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3928
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3930
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3938
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3940
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3948
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3950
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3958
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3960
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3968
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3970
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3978
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3980
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3988
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3990
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3998
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39A0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39A8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39B0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39B8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39C0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39C8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39D0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39D8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39E0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39E8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39F0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 39F8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A00
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A08
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A10
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A18
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A20
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A28
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A30
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A38
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A40
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A48
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A50
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A58
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A60
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A68
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A70
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A78
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A80
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A88
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A90
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3A98
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AA0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AA8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AB0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AB8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AC0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AC8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AD0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AD8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AE0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AE8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AF0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3AF8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B00
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B08
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B10
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B18
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B20
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B28
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B30
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B38
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B40
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B48
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B50
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B58
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B60
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B68
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B70
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B78
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B80
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B88
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B90
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3B98
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BA0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BA8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BB0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BB8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BC0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BC8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BD0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BD8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BE0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BE8
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BF0
     0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,0x3FFF,  // 3BF8
     0x3408,0x3490,0x341D,0x34C0,0x34FA,0x3401,0x34C0,0x34F2,  // 3C00
     0x3435,0x34C0,0x34F0,0x3431,0x34C0,0x34EE,0x3436,0x34C0,  // 3C08
     0x34EC,0x3432,0x34C0,0x34E4,0x3437,0x34C0,0x34E2,0x3433,  // 3C10
     0x34C7,0x34FF,0x34C0,0x34E4,0x3407,0x34C0,0x34DF,0x343F,  // 3C18
     0x34C8,0x34DC,0x3406,0x34C8,0x34DB,0x3401,0x34C8,0x34D7,  // 3C20
     0x3436,0x34C8,0x34D1,0x3432,0x34C8,0x34CF,0x3435,0x34C8,  // 3C28
     0x34C9,0x3431,0x34C8,0x34C7,0x3437,0x34C8,0x34C1,0x3433,  // 3C30
     0x34C8,0x34BF,0x34C4,0x34F6,0x3432,0x34C4,0x342B,0x3436,  // 3C38
     0x34C4,0x342F,0x3437,0x34C4,0x3482,0x3433,0x343F,0x340D,  // 3C40
     0x340A,0x344B,0x3469,0x3474,0x3462,0x3475,0x3467,0x342B,  // 3C48
     0x3420,0x343E,0x3420,0x3400,0x3421,0x3440,0x34E4,0x3452,  // 3C50
     0x349C,0x345B,0x34C4,0x34F6,0x3432,0x34C4,0x342B,0x3436,  // 3C58
     0x34C4,0x342F,0x3437,0x34C4,0x3482,0x3433,0x343F,0x340D,  // 3C60
     0x340A,0x3450,0x3443,0x3420,0x3420,0x3420,0x3450,0x3454,  // 3C68
     0x3452,0x3431,0x3420,0x3450,0x3454,0x3452,0x3432,0x3420,  // 3C70
     0x3441,0x3443,0x3420,0x3445,0x3458,0x3420,0x3453,0x3454,  // 3C78
     0x340D,0x340A,0x3400,0x34C4,0x342B,0x3435,0x34C4,0x34F7,  // 3C80
     0x3431,0x34C4,0x342E,0x3437,0x34C4,0x34E6,0x3433,0x34C5,  // 3C88
     0x3401,0x343F,0x34C5,0x3401,0x343F,0x34C7,0x3402,0x34C5,  // 3C90
     0x3401,0x343F,0x34C5,0x3401,0x343F,0x34C7,0x3402,0x34C5,  // 3C98
     0x3401,0x343F,0x34C5,0x3401,0x343F,0x34C5,0x3401,0x343F,  // 3CA0
     0x34C5,0x3401,0x343F,0x34C5,0x3401,0x343F,0x34C4,0x342C,  // 3CA8
     0x3437,0x34C4,0x3439,0x3433,0x343F,0x3440,0x34E4,0x344E,  // 3CB0
     0x349C,0x340D,0x34C4,0x3420,0x3432,0x34C4,0x3411,0x3436,  // 3CB8
     0x34C4,0x3409,0x3437,0x34C4,0x346F,0x3433,0x343F,0x3440,  // 3CC0
     0x34E4,0x343F,0x3498,0x3407,0x34C4,0x342D,0x3437,0x34C4,  // 3CC8
     0x347E,0x3433,0x343F,0x34C4,0x342F,0x3437,0x34C4,0x3482,  // 3CD0
     0x3433,0x343F,0x340D,0x340A,0x344B,0x3442,0x342B,0x3420,  // 3CD8
     0x3463,0x346F,0x346D,0x346D,0x3461,0x346E,0x3464,0x3473,  // 3CE0
     0x343A,0x3420,0x3444,0x3469,0x3473,0x3470,0x346C,0x3461,  // 3CE8
     0x3479,0x342C,0x3420,0x3447,0x346F,0x342C,0x3420,0x344C,  // 3CF0
     0x3469,0x3473,0x3474,0x342C,0x3420,0x344D,0x346F,0x3464,  // 3CF8
     0x3469,0x3466,0x3479,0x342C,0x3420,0x344E,0x3469,0x3462,  // 3D00
     0x346C,0x342C,0x3420,0x3454,0x3479,0x3470,0x3465,0x342C,  // 3D08
     0x3420,0x3452,0x3465,0x3467,0x3473,0x342C,0x3420,0x343F,  // 3D10
     0x340D,0x340A,0x3452,0x3465,0x3467,0x3473,0x3420,0x3450,  // 3D18
     0x3443,0x343D,0x3432,0x3442,0x3446,0x3437,0x342F,0x3438,  // 3D20
     0x342C,0x3420,0x3450,0x3431,0x343D,0x3432,0x3442,0x3446,  // 3D28
     0x3439,0x342F,0x3441,0x342C,0x3420,0x3450,0x3432,0x343D,  // 3D30
     0x3432,0x3442,0x3446,0x3442,0x342F,0x3443,0x342C,0x3420,  // 3D38
     0x3441,0x343D,0x3432,0x3442,0x3446,0x3444,0x342C,0x3420,  // 3D40
     0x3445,0x343D,0x3432,0x3442,0x3446,0x3445,0x342C,0x3420,  // 3D48
     0x3453,0x343D,0x3432,0x3442,0x3446,0x3446,0x340D,0x340A,  // 3D50
     0x3453,0x3465,0x3474,0x3420,0x3462,0x3472,0x346B,0x3470,  // 3D58
     0x3474,0x3420,0x3477,0x3469,0x3474,0x3468,0x3420,0x3461,  // 3D60
     0x346E,0x3420,0x3458,0x3450,0x3450,0x3443,0x3420,0x3450,  // 3D68
     0x3443,0x3420,0x3428,0x3424,0x3433,0x3446,0x3429,0x3400,  // 3D70
     0x34C4,0x342C,0x3437,0x34C4,0x3439,0x3433,0x343F,0x3440,  // 3D78
     0x34E4,0x3447,0x349C,0x3432,0x34C4,0x342E,0x3437,0x34C4,  // 3D80
     0x3482,0x3433,0x343F,0x34E4,0x340D,0x3498,0x3407,0x34C4,  // 3D88
     0x342E,0x3437,0x34C4,0x346B,0x3433,0x343F,0x34C6,0x3401,  // 3D90
     0x3435,0x34C6,0x3401,0x3431,0x34C4,0x342B,0x3437,0x34C4,  // 3D98
     0x34F7,0x3433,0x3435,0x34CF,0x3401,0x3431,0x34CF,0x3401,  // 3DA0
     0x34C4,0x342C,0x3437,0x34C4,0x3402,0x3433,0x343F,0x34C4,  // 3DA8
     0x342C,0x3437,0x34C4,0x3439,0x3433,0x343F,0x3440,0x34E4,  // 3DB0
     0x3454,0x3498,0x3409,0x3440,0x34E4,0x344D,0x349C,0x346C,  // 3DB8
     0x34C4,0x3400,0x3490,0x3402,0x34C4,0x3401,0x34CE,0x34FF,  // 3DC0
     0x34C4,0x342E,0x3437,0x34C4,0x3482,0x3433,0x343F,0x34E4,  // 3DC8
     0x340D,0x3498,0x3407,0x34C4,0x342E,0x3437,0x34C4,0x346B,  // 3DD0
     0x3433,0x343F,0x34C6,0x3401,0x3435,0x34C6,0x3401,0x3431,  // 3DD8
     0x3406,0x34D4,0x3420,0x349C,0x3407,0x34C4,0x342C,0x3437,  // 3DE0
     0x34C4,0x3439,0x3433,0x343F,0x3422,0x349C,0x3402,0x3490,  // 3DE8
     0x34F4,0x34C4,0x340D,0x3420,0x34C4,0x340A,0x3420,0x3435,  // 3DF0
     0x3401,0x3440,0x3435,0x34C4,0x342E,0x3437,0x34C4,0x34E6,  // 3DF8
     0x3433,0x3440,0x343F,0x3431,0x3401,0x3440,0x3431,0x3440,  // 3E00
     0x343F,0x34C5,0x3401,0x343F,0x34C2,0x3400,0x349C,0x34D0,  // 3E08
     0x3421,0x34E4,0x340D,0x3498,0x34CB,0x34E4,0x3415,0x3498,  // 3E10
     0x3496,0x34C4,0x342E,0x3437,0x34C4,0x347E,0x3433,0x343F,  // 3E18
     0x34E4,0x340D,0x349C,0x3448,0x34C6,0x3401,0x34C6,0x3401,  // 3E20
     0x34C9,0x34FF,0x3490,0x34B4,0x3440,0x34E4,0x3444,0x349C,  // 3E28
     0x3418,0x34C4,0x342E,0x3437,0x34C4,0x3482,0x3433,0x343F,  // 3E30
     0x34E4,0x340D,0x349C,0x3430,0x34C6,0x3401,0x3435,0x34C6,  // 3E38
     0x3401,0x3431,0x34C4,0x342F,0x3437,0x34C4,0x342A,0x3433,  // 3E40
     0x343F,0x3440,0x34E4,0x344C,0x349C,0x341E,0x34C4,0x34F6,  // 3E48
     0x3432,0x34C4,0x342B,0x3436,0x34C4,0x342E,0x3437,0x34C4,  // 3E50
     0x3482,0x3433,0x343F,0x34E4,0x340D,0x349C,0x340D,0x34C6,  // 3E58
     0x3401,0x3435,0x34C6,0x3401,0x3431,0x34C4,0x342F,0x3437,  // 3E60
     0x34C4,0x349E,0x3433,0x343F,0x34C4,0x340A,0x3420,0x34C4,  // 3E68
     0x343F,0x3420,0x34C4,0x340D,0x3420,0x34C4,0x340A,0x3420,  // 3E70
     0x34C4,0x342C,0x3437,0x34C4,0x3439,0x3433,0x343F,0x34C4,  // 3E78
     0x3401,0x3490,0x3402,0x34C4,0x3400,0x34CA,0x34FB,0x34C4,  // 3E80
     0x3476,0x3433,0x34CE,0x34FD,0x34C4,0x340F,0x3437,0x34CE,  // 3E88
     0x34FF,0x34C2,0x34FF,0x349C,0x3401,0x343F,0x34C4,0x3400,  // 3E90
     0x34CA,0x3403,0x34CA,0x3402,0x3440,0x3403,0x34FC,0x343A,  // 3E98
     0x3494,0x340F,0x3403,0x34FC,0x34F6,0x3494,0x3419,0x34C6,  // 3EA0
     0x3401,0x3437,0x34C6,0x3401,0x3433,0x3440,0x343F,0x3490,  // 3EA8
     0x34D2,0x3403,0x34FC,0x340D,0x3494,0x34F1,0x3403,0x34FC,  // 3EB0
     0x34FA,0x3494,0x3402,0x3490,0x34EA,0x3402,0x34F4,0x340A,  // 3EB8
     0x34CA,0x34FF,0x34C4,0x3404,0x34CA,0x34FE,0x3402,0x34C2,  // 3EC0
     0x3403,0x34F2,0x3403,0x34CA,0x3403,0x34C2,0x3402,0x34F2,  // 3EC8
     0x3402,0x34CA,0x3402,0x34BA,0x34FE,0x349C,0x34EF,0x3402,  // 3ED0
     0x34C2,0x3403,0x34F2,0x34FF,0x34CA,0x3403,0x343F,0x3490,  // 3ED8
     0x34BB,0x34CE,0x34FF,0x34C4,0x3420,0x3490,0x3404,0x34CE,  // 3EE0
     0x34FF,0x34C4,0x3400,0x34CE,0x34FF,0x34C4,0x34C1,0x3433,  // 3EE8
     0x34CE,0x34FF,0x34C4,0x340F,0x3437,0x34CE,0x34FF,0x34C4,  // 3EF0
     0x3402,0x34CE,0x34FF,0x34C2,0x3404,0x341C,0x341C,0x341C,  // 3EF8
     0x341C,0x3402,0x34F4,0x34F6,0x3494,0x3404,0x34F4,0x343A,  // 3F00
     0x3490,0x3402,0x34F4,0x3440,0x343F,0x34BA,0x3400,0x3498,  // 3F08
     0x3406,0x34C2,0x3404,0x34D4,0x340F,0x3490,0x34EA,0x34C2,  // 3F10
     0x3403,0x3498,0x3401,0x343F,0x34C2,0x3401,0x3437,0x34C2,  // 3F18
     0x3402,0x3433,0x34C6,0x3404,0x34C6,0x3401,0x343F,0x3490,  // 3F20
     0x34B8,0x3490,0x34BC,0x34C4,0x34F6,0x3432,0x34C4,0x342B,  // 3F28
     0x3436,0x34C4,0x3408,0x34CA,0x34F7,0x34C4,0x3410,0x34CA,  // 3F30
     0x34F8,0x34C4,0x340D,0x3420,0x34C4,0x340A,0x3420,0x3435,  // 3F38
     0x3401,0x3440,0x3435,0x34C4,0x342E,0x3437,0x34C4,0x34E6,  // 3F40
     0x3433,0x3440,0x343F,0x3431,0x3401,0x3440,0x3431,0x3440,  // 3F48
     0x343F,0x34C5,0x3401,0x343F,0x34BA,0x34F8,0x349C,0x34F9,  // 3F50
     0x34C4,0x3420,0x3420,0x34C5,0x34F0,0x34C4,0x3410,0x34CA,  // 3F58
     0x34F8,0x34C5,0x3401,0x3494,0x3402,0x34C4,0x342E,0x34D4,  // 3F60
     0x347F,0x3403,0x34FC,0x3420,0x3494,0x3402,0x34C4,0x340E,  // 3F68
     0x3402,0x34F4,0x3420,0x3420,0x34BA,0x34F8,0x349C,0x34E9,  // 3F70
     0x34BA,0x34F7,0x349C,0x34B9,0x34C4,0x342C,0x3437,0x34C4,  // 3F78
     0x3439,0x3433,0x343F,0x3433,0x3431,0x3437,0x3435,0x34C5,  // 3F80
     0x3401,0x34C4,0x340F,0x3437,0x34C4,0x34C1,0x3433,0x34C5,  // 3F88
     0x3401,0x3498,0x3403,0x343F,0x3490,0x34F9,0x34C5,0x34FF,  // 3F90
     0x3431,0x3433,0x3435,0x3437,0x343F,0x3490,0x34E4,0x34C4,  // 3F98
     0x34F6,0x3432,0x34C4,0x342B,0x3436,0x34C4,0x3410,0x34CA,  // 3FA0
     0x34F7,0x34C4,0x340D,0x3420,0x34C4,0x340A,0x3420,0x3435,  // 3FA8
     0x3401,0x3440,0x3435,0x34C4,0x342E,0x3437,0x34C4,0x34E6,  // 3FB0
     0x3433,0x3440,0x343F,0x3431,0x3401,0x3440,0x3431,0x3440,  // 3FB8
     0x343F,0x34C5,0x3401,0x343F,0x34C1,0x34FF,0x3494,0x3403,  // 3FC0
     0x34C5,0x3401,0x343F,0x34BA,0x34F7,0x349C,0x34DA,0x34C4,  // 3FC8
     0x342C,0x3437,0x34C4,0x3439,0x3433,0x343F,0x34C0,0x3427,  // 3FD0
     0x3437,0x34C0,0x3425,0x3433,0x34C7,0x34FF,0x343F,0x3400,  // 3FD8
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 3FE0
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 3FE8
     0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,0x3400,  // 3FF0
     0x3400,0x3400,0x3400,0x3400,0x3490,0x34D8,0x3428,0x3400,  // 3FF8
   };
   const int pg3len = sizeof(pg3)/2;

  /******************************************************************************
   *                                                                            *
   ******************************************************************************/

   #define RX_READY   (UCSR0A & 1<<RXC0)  //
   #define TX_READY   (UCSR0A & 1<<UDRE0) //

   void put232(uint8_t data)          // ****************************************
   { while(!TX_READY); UDR0 = data;   // send character                         *
   }                                  // ****************************************

   void putStr(char *data)            // ****************************************
   { while(*data) put232(*data++);    // send string variable                   *
   }                                  // ****************************************
  /*                                                                            *
   *  overload function for FlashStringHelper string constants                  *
   *                                                                            */
   void putStr(const __FlashStringHelper *ifsh)
   { PGM_P p = reinterpret_cast<PGM_P>(ifsh); 
     while(char c = pgm_read_byte(p++)) 
       put232(c);
   }

   uint8_t rxAvail(void)              // ****************************************
   { if(RX_READY)                     //                                        *
       return 1;                      //                                        *
     else                             //                                        *
       return 0;                      //                                        *
   }                                  // ****************************************

   uint8_t get232(void)               // ****************************************
   { return (uint8_t) UDR0;           //                                        *
   }                                  // ****************************************

   void putHex(byte work)             // ****************************************
   { put232(hex[hiNibble(work)]);     //                                        *
     put232(hex[loNibble(work)]);     //                                        *
   }                                  // ****************************************

  /******************************************************************************
   *                                                                            *
   ******************************************************************************/

   void send_8(uint8_t data)          // ****************************************
   { datOut();                        // output                                 *
     for(byte i=0; i<8; i++)          //                                        *
     { if(data & 0x80)                //                                        *
         icspDat(1);                  //                                        *
       else                           //                                        *
         icspDat(0);                  //                                        *
       _delay_us(2);                  //                                        *
       icspClk(1); _delay_us(1);      // clk hi                                 *
       data = data << 1;              // prep for next bit                      *
       icspClk(0);                    // clk lo                                 *
       icspDat(0);                    // dat lo                                 *
     }                                //                                        *
   }                                  // ****************************************

   void send_24(unsigned long data)   // ****************************************
   { datOut();                        // output                                 *
     for(byte i=0; i<23; i++)         //                                        *
     { if(data & 0x400000)            //                                        *
         icspDat(1);                  //                                        *
       else                           //                                        *
         icspDat(0);                  //                                        *
       _delay_us(1);                  //                                        *
       icspClk(1); _delay_us(2);      // clk hi                                 *
       data = data << 1;              // prep for next bit                      *
       icspClk(0);                    // clk lo                                 *
     }                                //                                        *
     icspDat(0); _delay_us(2);        // send 'stop' bit                        *
     icspClk(1); _delay_us(2);        //  "                                     *
     icspClk(0);                      //  "                                     *
   }                                  // ****************************************

   uint8_t enterProgMode(void)        // ****************************************
   { icspVcc(1);                      // turn Vcc on                            *
     _delay_us(300);                  //                                        *
     send_8(0x4D);                    // 'M'                                    *
     send_8(0x43);                    // 'C'                                    *
     send_8(0x48);                    // 'H'                                    *
     send_8(0x50);                    // 'P'                                    *
     _delay_us(300);                  //                                        *
   }                                  // ****************************************

   uint16_t read_24()                 // ****************************************
   { unsigned int out = 0;            //                                        *
     datInp();                        // input                                  *
     for(byte i=0; i<23; i++)         //                                        *
     { icspClk(1); _delay_us(1);      // clk hi                                 *
       out <<= 1;                     // make room for new bit                  *
       icspClk(0); _delay_us(1);      // clk lo                                 *
       if(PIND & _BV(dat)) out |= 1;  // get new bit                            *
     }                                //                                        *
     icspClk(1); _delay_us(1);        // read 'stop' bit                        *
     icspClk(0);                      //  "                                     *
     return out;                      //                                        *
   }                                  // ****************************************

   void set_pc(unsigned long pc)      // ****************************************
   { send_8(0x80);                    //                                        *
    _delay_us(2);                     //                                        *
     send_24(pc);                     //                                        *
   }                                  // ****************************************

   void bulk_erase()                  // ****************************************
   { enterProgMode();                 // enter program mode                     *
     send_8(0x18);                    // bulk erase                             *
     _delay_ms(100);                  //                                        *
     exitProgMode();                  // exit program mode                      *
   }                                  // ****************************************

   void load_nvm(uint16_t data, unsigned char inc)
   { if(inc)                          //                                        *
       send_8(0x02);                  //                                        *
     else                             //                                        *
       send_8(0x00);                  //                                        *
     _delay_us(1);                    //                                        *
     send_24(data);                   //                                        *
     _delay_us(1);                    //                                        *
   }                                  // ****************************************

   uint16_t read_nvm(byte inc)        // ****************************************
   { uint16_t retval;                 //                                        *
     if(inc == 1)                     //                                        *
       send_8(0xFE);                  //                                        *
     else                             //                                        *
       send_8(0xFC);                  //                                        *
     _delay_us(1);                    //                                        *
     retval = read_24();              //                                        *
     return retval;                   //                                        *
   }                                  // ****************************************

   void begin_prog(unsigned char cfg_bit)
   { send_8(0xE0);                    // ****************************************
     _delay_ms(3);                    //                                        *
     if(cfg_bit!=0) _delay_ms(3);     //                                        *
   }                                  // ****************************************

   void write_row(unsigned long addr, const uint16_t *image, uint16_t ndx)
   { set_pc(addr);                    // 16F153xx algorithm                     *
     for(uint16_t i=0; i<32; i++)     //                                        *
     { load_nvm(rom(image+ndx+i),1);  //                                        *
     }                                //                                        *
     set_pc(addr);                    // reset 'row' address                    *
     begin_prog(0);                   //                                        *
   }                                  // ****************************************

   void blank()                       // ****************************************
   { enterProgMode();                 // enter program mode                     *
     set_pc(0x0000);                  //                                        *
     for(uint16_t i=0; i<32768; i++)  //                                        *
     { if(read_nvm(1) != 0x3FFF)      //                                        *
       { putStr(F(" not erased\n"));  //                                        *
         exitProgMode();              // exit program mode                      *
         return;                      //                                        *
       }                              //                                        *
     }                                //                                        *
     exitProgMode();                  // exit program mode                      *
     putStr(F(" erased\n"));          //                                        *
   }                                  // ****************************************

   bool pause()                       // ****************************************
   { if(rxAvail())                    //                                        *
     { if(get232() == 3)              // if Ctrl-C                              *
         return true;                 //                                        *
       while(!rxAvail());             // pause listing                          *
       if(get232() == 3)              // if Ctrl-C                              *
         return true;                 //                                        *
     }                                //                                        *
     return false;                    //                                        *
   }                                  // ****************************************

   void disp_pgm(uint32_t addr, uint32_t end)
   { unsigned int mem;                //                                        *
     enterProgMode();                 // enter program mode                     *
     addr &= 0xFFFFFFF8;              // start on 8 byte boundary               *
     set_pc(addr);                    //                                        *
     do                               //                                        *
     { if((addr & 0x07) == 0)         // if new 'row'                           *
       { put232('\n');                //                                        *
         if(pause())                  // if pause() returns ^C                  *
         { exitProgMode();            // terminate display function             *
           return;                    //                                        *
         }                            //                                        *
         put232(' ');                 //                                        *
         putHex(ul(addr));            // *** Q40                                *
         putHex(hi(addr));            //                                        *
         putHex(lo(addr));            //                                        *
         put232(':');                 //                                        *
       }                              //                                        *
       put232(' ');                   //                                        *
       mem = read_nvm(1);             //                                        *
       putHex(hi(mem));               //                                        *
       putHex(lo(mem));               //                                        *
     } while(addr++ != end);          //                                        *
     exitProgMode();                  // exit program mode                      *
     put232('\n');                    //                                        *
   }                                  // ****************************************

   void write_cfg(unsigned int data, unsigned long addr)
   { set_pc(addr);                    //
     load_nvm(data,0);                //
     begin_prog(1);                   //
   }                                  //

  /******************************************************************************
   *                                                                            *
   ******************************************************************************/

   byte hexDigit(int c)               // ****************************************
   { if((c >= '0') && (c <= '9'))     //                                        *
       return c - '0';                //                                        *
     if((c >= 'a') && (c <= 'f'))     //                                        *
       return c - 'a' + 10;           //                                        *
     if((c >= 'A') && (c <= 'F'))     //                                        *
       return c + 10 - 'A';           //                                        *
     return 0xff;                     //                                        *
   }                                  // ****************************************

   uint32_t getHex32(char *& pData, uint32_t defaultValue = 0)
   { uint32_t u32 = 0;                //                                        *
     while(!isxdigit(*pData))++pData; // skip extra cmd characters              *
     if(isxdigit(*pData))             // if 'hex' character                     *
     { while(isxdigit(*pData))        //                                        *
       { u32 <<= 4;                   //                                        *
         u32 |= hexDigit(*pData++);   //                                        *
       }                              //                                        *
     }                                //                                        *
     else                             //                                        *
     { u32 = defaultValue;            //                                        *
     }                                //                                        *
     return u32;                      //                                        *
   }                                  // ****************************************

   char * rdLine(char *buff, int len) // ****************************************
   { for(int ix = 0; (ix<len); ix++)  //                                        *
     { buff[ix] = 0;                  //                                        *
     }                                //                                        *
     char c = ' '; int ix = 0;        //                                        *
     do                               //                                        *
     { if(rxAvail())                  //                                        *
       { put232(c = get232());        //                                        *
         if((c == '\b') && (ix > 0))  //                                        *
           --ix;                      // back space                             *
         else                         //                                        *
           buff[ix++] = c;            //                                        *
       }                              //                                        *
     } while((c != '\n') && (c != '\r') && (ix < len));
     buff[ix - 1] = 0;                //                                        *
     return buff;                     //                                        *
   }                                  // ****************************************

  /******************************************************************************
   *                                                                            *
   ******************************************************************************/

   #define _BAUD (115200/2)           // 57600 or 115200 (double speed)
   #define _UBRR (F_CPU/16)/_BAUD-1   // Used for UBRRL and UBRRH 

   void setup()                       // ****************************************
   { DDRD |= 0b00111110;              // clr/dat/clk/vcc (D5..D2) Outputs       *
     icspVcc(0);                      // vcc(PD2/D2) = 0                        *
     icspClk(0);                      // clk(PD3/D3) = 0                        *
     icspDat(0);                      // dat(PD4/D4) = 0                        *
     icspClr(0);                      // clr(PD5/D5) = 0                        *
     UBRR0 = _UBRR;                   // setup USART                            *
     UCSR0A |= _BV(U2X0);             //  " (57600 x 2 for 115200 baud)         *
     UCSR0B |= _BV(TXEN0);            //  "                                     *
     UCSR0B |= _BV(RXEN0);            //  "                                     *
     UCSR0C  = 3<<UCSZ00;             // async' 8/N/1                           *
     put232('\n');                    //                                        *
     putStr(F(" 16F18877 Programmer - PICL firmware r20220324"));
     putStr(F(" Mike McLaren, K8LH \n\r\n"));
     putStr(F(" 8K 'STD' PCB, 20-MHz (20-MHz xtal), 9600 baud\n"));
   }                                  // ****************************************

  /******************************************************************************
   *                                                                            *
   ******************************************************************************/

   char line[120];                    //
   uint32_t addr1 = 0;                //
   uint32_t addr2 = 0xFF;             //

   void loop()                            // ************************************
   { char c,i;                            //                                    *
     uint16_t address,index;              // programming address                *
     unsigned int dev;                    // device id                          *
     unsigned int rev;                    // device rev                         *
     put232('\n');                        //                                    *
     put232('>');                         //                                    *
     rdLine(line, sizeof(line));          //                                    *
     byte cmd = line[0];                  //                                    *
     char * pCursor = line + 1;           // position 'sssss' param             *
     addr1 = getHex32(pCursor,0);         //                                    *
     addr2 = getHex32(pCursor,addr1+255); //                                    *
     if(cmd >= 'A' && cmd <= 'Z')         // if in range 'A'..'Z'               *
     { cmd |= 0x20;                       // convert to lower case              *
     }                                    //                                    *
     switch(cmd)                          //                                    *
     { case 'd':                          // dump/display memory                *
         disp_pgm(addr1, addr2);          //                                    *
         break;                           //                                    *
       case 'b':                          // blank check                        *
         blank();                         //                                    *
         break;                           //                                    *
       case 'e':                          // erase chip                         *
         bulk_erase();                    //                                    *
         putStr(F(" done\n"));            //                                    *
         break;                           //                                    *
       case 'i':                          // read & display chip ID & rev       *
         enterProgMode();                 // enter program mode                 *
         set_pc(0x8005);                  //                                    *
         rev = read_nvm(1);               // read chip rev                      *
         dev = read_nvm(1);               // read chip ID                       *
         exitProgMode();                  // exit program mode                  *
         putStr(F("\n Chip ID "));        //                                    *
         putHex(hi(dev));                 //                                    *
         putHex(lo(dev));                 //                                    *
         putStr(F(" rev "));              //                                    *
         putHex(hi(rev));                 //                                    *
         putHex(lo(rev));                 //                                    *
         if(dev == 0x30BE) putStr(F(" 16F15313 "));   //                        *
         if(dev == 0x30C0) putStr(F(" 16F15323 "));   //                        *
         if(dev == 0x30C2) putStr(F(" 16F15324 "));   //                        *
         if(dev == 0x30C6) putStr(F(" 16F15325 "));   //                        *
         if(dev == 0x30C4) putStr(F(" 16F15344 "));   //                        *
         if(dev == 0x30C8) putStr(F(" 16F15345 "));   //                        *
         if(dev == 0x30AD) putStr(F(" 16F15354 "));   //                        *
         if(dev == 0x30AE) putStr(F(" 16F15355 "));   //                        *
         if(dev == 0x30B0) putStr(F(" 16F15356 "));   //                        *
         if(dev == 0x30B2) putStr(F(" 16F15375 "));   //                        *
         if(dev == 0x30B4) putStr(F(" 16F15376 "));   //                        *
         if(dev == 0x30B6) putStr(F(" 16F15385 "));   // TQFP/UQFN package      *
         if(dev == 0x30B8) putStr(F(" 16F15386 "));   // TQFP/UQFN package      *
         if(dev == 0x3075) putStr(F(" 16F18877 "));   // DIP-40                 *
         put232('\n');                    //                                    *
         break;                           // ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
       case 'p':                          // program 16F18877 (PICL)            *
         put232('\n');                    //                                    *
         putStr(F(" Erase . ."));         //                                    *
         bulk_erase();                    // bulk erase                         *
         putStr(F(" done\n"));            //                                    *
         putStr(F(" Program ."));         //                                    *
         enterProgMode();                 // enter program mode                 *
         address = 0x0000; index = 0;     // ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
         while(index < sizeof(pg0)/2)     //                                    *
         { write_row(address,pg0,index);  // write a 32 word 'row'              *
           index += 32; address += 32;    // next 'row'                         *
         }                                //                                    *
         address = 0x3000; index = 0;     // ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
         while(index < sizeof(pg3)/2)     //                                    *
         { write_row(address,pg3,index);  // write a 32 word 'row'              *
           index += 32; address += 32;    // next 'row'                         *
         }                                //                                    *
         putStr(F(" done\n"));            // ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
         putStr(F(" Config  ."));         //                                    *
         for(i = 0; i < 5; i++)           //                                    *
         { write_cfg(rom(cfgmem+i),0x8007+i);
         }                                //                                    *
         putStr(F(" done\n"));            //                                    *
         exitProgMode();                  //                                    *
         break;                           // ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
       default:                           //                                    *
         put232('\n');                    //                                    *
         putStr(F(" Blank test\n"));      //                                    *
         putStr(F(" Erase chip\n"));      //                                    *
         putStr(F(" ID  \n"));            //                                    *
         putStr(F(" Dump ssss eeee\n"));  //                                    *
         putStr(F(" Program 16F18877\n"));
         break;                           //                                    *
     }                                    //                                    *
   }                                      // ************************************
